=== modified file 'NEWS'
--- NEWS	2008-05-04 20:23:56 +0000
+++ NEWS	2008-05-23 13:14:58 +0000
@@ -1,5 +1,17 @@
 0.95.0	UNRELEASED
 
+ BUG FIXES
+
+  * Replace _() calls by _i18n() calls. (Vincent Ladeuil, #187283)
+  
+  * Fixed adding tags. (Javier Derderian, #228709)
+
+ INTERNALS
+
+  * All i18n calls should now go through _i18n which must be imported from
+    bzrlib.plugins.gtk. This addresses the occasional collisions with '_' used
+    as an anonymous variable. (Vincent Ladeuil)
+
 
 0.94.0    2008-05-04
 

=== modified file '__init__.py'
--- __init__.py	2008-05-04 20:23:56 +0000
+++ __init__.py	2008-05-22 03:43:15 +0000
@@ -193,12 +193,12 @@
             if revision is not None:
                 if len(revision) == 1:
                     tree1 = wt
-                    revision_id = revision[0].in_history(branch).rev_id
+                    revision_id = revision[0].as_revision_id(tree1.branch)
                     tree2 = branch.repository.revision_tree(revision_id)
                 elif len(revision) == 2:
-                    revision_id_0 = revision[0].in_history(branch).rev_id
+                    revision_id_0 = revision[0].as_revision_id(branch)
                     tree2 = branch.repository.revision_tree(revision_id_0)
-                    revision_id_1 = revision[1].in_history(branch).rev_id
+                    revision_id_1 = revision[1].as_revision_id(branch)
                     tree1 = branch.repository.revision_tree(revision_id_1)
             else:
                 tree1 = wt
@@ -261,8 +261,7 @@
             if revision is None:
                 revids.append(br.last_revision())
             else:
-                (revno, revid) = revision[0].in_history(br)
-                revids.append(revid)
+                revids.append(revision[0].as_revision_id(br))
         import gtk
         pp = start_viz_window(br, revids, limit)
         pp.connect("destroy", lambda w: gtk.main_quit())
@@ -312,7 +311,7 @@
         if revision is not None:
             if len(revision) != 1:
                 raise BzrCommandError("Only 1 revion may be specified.")
-            revision_id = revision[0].in_history(br).rev_id
+            revision_id = revision[0].as_revision_id(br)
             tree = br.repository.revision_tree(revision_id)
         else:
             revision_id = getattr(tree, 'get_revision_id', lambda: None)()
@@ -359,8 +358,8 @@
             br = wt.branch
         except NoWorkingTree, e:
             from dialog import error_dialog
-            error_dialog(_('Directory does not have a working tree'),
-                         _('Operation aborted.'))
+            error_dialog(_i18n('Directory does not have a working tree'),
+                         _i18n('Operation aborted.'))
             return 1 # should this be retval=3?
 
         # It is a good habit to keep things locked for the duration, but it
@@ -393,7 +392,7 @@
         
         if revision is not None:
             try:
-                revision_id = revision[0].in_history(wt.branch).rev_id
+                revision_id = revision[0].as_revision_id(wt.branch)
             except:
                 from bzrlib.errors import BzrError
                 raise BzrError('Revision %r doesn\'t exist' % revision[0].user_spec )
@@ -705,18 +704,20 @@
 
     def run(self, path):
         try:
-            from bzrlib.plugins.gtk.diff import (DiffWindow,
-                                                 MergeDirectiveWindow)
-            lines = open(path, 'rb').readlines()
+            from bzrlib.plugins.gtk.diff import (DiffController,
+                                                 MergeDirectiveController)
+            if path == '-':
+                lines = sys.stdin.readlines()
+            else:
+                lines = open(path, 'rb').readlines()
             lines = [l.replace('\r\n', '\n') for l in lines]
             try:
                 directive = merge_directive.MergeDirective.from_lines(lines)
             except errors.NotAMergeDirective:
-                window = DiffWindow()
-                window.set_diff_text(path, lines)
+                controller = DiffController(path, lines)
             else:
-                window = MergeDirectiveWindow(directive, path)
-                window.set_diff_text(path, directive.patch.splitlines(True))
+                controller = MergeDirectiveController(path, directive)
+            window = controller.window
             window.show()
             gtk = self.open_display()
             window.connect("destroy", gtk.main_quit)
@@ -733,6 +734,9 @@
 import gettext
 gettext.install('olive-gtk')
 
+# Let's create a specialized alias to protect '_' from being erased by other
+# uses of '_' as an anonymous variable (think pdb for one).
+_i18n = gettext.gettext
 
 class NoDisplayError(BzrCommandError):
     """gtk could not find a proper display"""

=== modified file 'branch.py'
--- branch.py	2008-03-07 16:01:35 +0000
+++ branch.py	2008-05-05 18:16:46 +0000
@@ -29,6 +29,8 @@
 from bzrlib.branch import Branch
 import bzrlib.errors as errors
 
+from bzrlib.plugins.gtk import _i18n
+
 from dialog import error_dialog, info_dialog
 
 from branchbox import BranchSelectionBox
@@ -47,15 +49,15 @@
         self.path = path
         
         # Create the widgets
-        self._button_branch = gtk.Button(_("_Branch"), use_underline=True)
+        self._button_branch = gtk.Button(_i18n("_Branch"), use_underline=True)
         self._remote_branch = BranchSelectionBox()
         self._button_revision = gtk.Button('')
-        self._label_location = gtk.Label(_("Branch location:"))
+        self._label_location = gtk.Label(_i18n("Branch location:"))
         self._label_location.set_alignment(0, 0.5)
-        self._label_destination = gtk.Label(_("Destination:"))
-        self._label_nick = gtk.Label(_("Branck nick:"))
-        self._label_revision = gtk.Label(_("Revision:"))
-        self._filechooser = gtk.FileChooserButton(_("Please select a folder"))
+        self._label_destination = gtk.Label(_i18n("Destination:"))
+        self._label_nick = gtk.Label(_i18n("Branck nick:"))
+        self._label_revision = gtk.Label(_i18n("Revision:"))
+        self._filechooser = gtk.FileChooserButton(_i18n("Please select a folder"))
         self._filechooser.set_action(gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER)
         self._hbox_revision = gtk.HBox()
         self._entry_revision = gtk.Entry()
@@ -135,8 +137,8 @@
         """ Branch button clicked handler. """
         location = self._remote_branch.get_url()
         if location is '':
-            error_dialog(_('Missing branch location'),
-                         _('You must specify a branch location.'))
+            error_dialog(_i18n('Missing branch location'),
+                         _i18n('You must specify a branch location.'))
             return
         
         destination = self._filechooser.get_filename()
@@ -177,8 +179,8 @@
         finally:
             br_from.unlock()
                 
-        info_dialog(_('Branching successful'),
-                    _('%d revision(s) branched.') % revs)
+        info_dialog(_i18n('Branching successful'),
+                    _i18n('%d revision(s) branched.') % revs)
         
         self.response(gtk.RESPONSE_OK)
     
@@ -186,7 +188,7 @@
         """ We try to get the last revision if focus lost. """
         rev = self._get_last_revno()
         if rev is None:
-            self._entry_revision.set_text(_('N/A'))
+            self._entry_revision.set_text(_i18n('N/A'))
             self._button_revision.set_sensitive(False)
         else:
             self._entry_revision.set_text(str(rev))

=== modified file 'branchview/treeview.py'
--- branchview/treeview.py	2008-04-24 15:26:14 +0000
+++ branchview/treeview.py	2008-05-05 18:16:46 +0000
@@ -14,6 +14,7 @@
 import re
 import treemodel
 
+from bzrlib.plugins.gtk import _i18n
 from linegraph import linegraph, same_branch
 from graphcell import CellRendererGraph
 from treemodel import TreeModel
@@ -397,7 +398,8 @@
                                                  gtk.ICON_SIZE_BUTTON)
         image_loading.show()
         
-        label_loading = gtk.Label(_("Please wait, loading ancestral graph..."))
+        label_loading = gtk.Label(
+            _i18n("Please wait, loading ancestral graph..."))
         label_loading.set_alignment(0.0, 0.5)
         label_loading.show()
         

=== modified file 'checkout.py'
--- checkout.py	2007-05-17 16:12:27 +0000
+++ checkout.py	2008-05-05 18:16:46 +0000
@@ -24,6 +24,7 @@
 
 import gtk
 
+from bzrlib.plugins.gtk import _i18n
 from errors import show_bzr_error
 
 from bzrlib.branch import Branch
@@ -47,19 +48,19 @@
         self.path = path
         
         # Create the widgets
-        self._button_checkout = gtk.Button(_("Check_out"), use_underline=True)
+        self._button_checkout = gtk.Button(_i18n("Check_out"), use_underline=True)
         self._button_revision = gtk.Button('')
         self._image_browse = gtk.Image()
-        self._filechooser = gtk.FileChooserButton(_("Please select a folder"))
+        self._filechooser = gtk.FileChooserButton(_i18n("Please select a folder"))
         self._combo = gtk.ComboBoxEntry()
-        self._label_location = gtk.Label(_("Branch location:"))
-        self._label_destination = gtk.Label(_("Destination:"))
-        self._label_nick = gtk.Label(_("Branck nick:"))
-        self._label_revision = gtk.Label(_("Revision:"))
+        self._label_location = gtk.Label(_i18n("Branch location:"))
+        self._label_destination = gtk.Label(_i18n("Destination:"))
+        self._label_nick = gtk.Label(_i18n("Branck nick:"))
+        self._label_revision = gtk.Label(_i18n("Revision:"))
         self._hbox_revision = gtk.HBox()
         self._entry_revision = gtk.Entry()
         self._entry_nick = gtk.Entry()
-        self._check_lightweight = gtk.CheckButton(_("_Lightweight checkout"),
+        self._check_lightweight = gtk.CheckButton(_i18n("_Lightweight checkout"),
                                                   use_underline=True)
         
         # Set callbacks
@@ -160,8 +161,8 @@
         """ Checkout button clicked handler. """
         location = self._combo.get_child().get_text()
         if location is '':
-            error_dialog(_('Missing branch location'),
-                         _('You must specify a branch location.'))
+            error_dialog(_i18n('Missing branch location'),
+                         _i18n('You must specify a branch location.'))
             return
         
         destination = self._filechooser.get_filename()
@@ -192,7 +193,7 @@
         """ We try to get the last revision if focus lost. """
         rev = self._get_last_revno()
         if rev is None:
-            self._entry_revision.set_text(_('N/A'))
+            self._entry_revision.set_text(_i18n('N/A'))
             self._button_revision.set_sensitive(False)
         else:
             self._entry_revision.set_text(str(rev))

=== modified file 'commit.py'
--- commit.py	2008-03-11 13:18:28 +0000
+++ commit.py	2008-05-05 18:16:46 +0000
@@ -31,6 +31,7 @@
 from bzrlib.trace import mutter
 from bzrlib.util import bencode
 
+from bzrlib.plugins.gtk import _i18n
 from dialog import error_dialog, question_dialog
 from errors import show_bzr_error
 
@@ -164,12 +165,12 @@
         store = self._files_store
         self._treeview_files.set_model(None)
 
-        added = _('added')
-        removed = _('removed')
-        renamed = _('renamed')
-        renamed_and_modified = _('renamed and modified')
-        modified = _('modified')
-        kind_changed = _('kind changed')
+        added = _i18n('added')
+        removed = _i18n('removed')
+        renamed = _i18n('renamed')
+        renamed_and_modified = _i18n('renamed and modified')
+        modified = _i18n('modified')
+        kind_changed = _i18n('kind changed')
 
         # The store holds:
         # [file_id, real path, checkbox, display path, changes type, message]
@@ -257,7 +258,7 @@
             self._enable_per_file_commits = True
         if not self._enable_per_file_commits:
             self._file_message_expander.hide()
-            self._global_message_label.set_markup(_('<b>Commit Message</b>'))
+            self._global_message_label.set_markup(_i18n('<b>Commit Message</b>'))
 
     def _compute_delta(self):
         self._delta = self._wt.changes_from(self._basis_tree)
@@ -307,7 +308,7 @@
         self._construct_file_list()
         self._construct_pending_list()
 
-        self._check_local = gtk.CheckButton(_("_Only commit locally"),
+        self._check_local = gtk.CheckButton(_i18n("_Only commit locally"),
                                             use_underline=True)
         self._left_pane_box.pack_end(self._check_local, False, False)
         self._check_local.set_active(False)
@@ -334,7 +335,7 @@
         self._hpane.pack2(self._right_pane_table, resize=True, shrink=True)
 
     def _construct_action_pane(self):
-        self._button_commit = gtk.Button(_("Comm_it"), use_underline=True)
+        self._button_commit = gtk.Button(_i18n("Comm_it"), use_underline=True)
         self._button_commit.connect('clicked', self._on_commit_clicked)
         self._button_commit.set_flags(gtk.CAN_DEFAULT)
         self._button_commit.show()
@@ -360,24 +361,24 @@
 
     def _construct_file_list(self):
         self._files_box = gtk.VBox(homogeneous=False, spacing=0)
-        file_label = gtk.Label(_('Files'))
+        file_label = gtk.Label(_i18n('Files'))
         # file_label.show()
         self._files_box.pack_start(file_label, expand=False)
 
         self._commit_all_files_radio = gtk.RadioButton(
-            None, _("Commit all changes"))
+            None, _i18n("Commit all changes"))
         self._files_box.pack_start(self._commit_all_files_radio, expand=False)
         self._commit_all_files_radio.show()
         self._commit_all_files_radio.connect('toggled',
             self._toggle_commit_selection)
         self._commit_selected_radio = gtk.RadioButton(
-            self._commit_all_files_radio, _("Only commit selected changes"))
+            self._commit_all_files_radio, _i18n("Only commit selected changes"))
         self._files_box.pack_start(self._commit_selected_radio, expand=False)
         self._commit_selected_radio.show()
         self._commit_selected_radio.connect('toggled',
             self._toggle_commit_selection)
         if self._pending:
-            self._commit_all_files_radio.set_label(_('Commit all changes*'))
+            self._commit_all_files_radio.set_label(_i18n('Commit all changes*'))
             self._commit_all_files_radio.set_sensitive(False)
             self._commit_selected_radio.set_sensitive(False)
 
@@ -410,15 +411,15 @@
         crt.set_property('activatable', not bool(self._pending))
         crt.connect("toggled", self._toggle_commit, self._files_store)
         if self._pending:
-            name = _('Commit*')
+            name = _i18n('Commit*')
         else:
-            name = _('Commit')
+            name = _i18n('Commit')
         commit_col = gtk.TreeViewColumn(name, crt, active=2)
         commit_col.set_visible(False)
         self._treeview_files.append_column(commit_col)
-        self._treeview_files.append_column(gtk.TreeViewColumn(_('Path'),
+        self._treeview_files.append_column(gtk.TreeViewColumn(_i18n('Path'),
                                            gtk.CellRendererText(), text=3))
-        self._treeview_files.append_column(gtk.TreeViewColumn(_('Type'),
+        self._treeview_files.append_column(gtk.TreeViewColumn(_i18n('Type'),
                                            gtk.CellRendererText(), text=4))
         self._treeview_files.connect('cursor-changed',
                                      self._on_treeview_files_cursor_changed)
@@ -451,11 +452,11 @@
 
         pending_message = gtk.Label()
         pending_message.set_markup(
-            _('<i>* Cannot select specific files when merging</i>'))
+            _i18n('<i>* Cannot select specific files when merging</i>'))
         self._pending_box.pack_start(pending_message, expand=False, padding=5)
         pending_message.show()
 
-        pending_label = gtk.Label(_('Pending Revisions'))
+        pending_label = gtk.Label(_i18n('Pending Revisions'))
         self._pending_box.pack_start(pending_label, expand=False, padding=0)
         pending_label.show()
 
@@ -477,11 +478,11 @@
                                  )
         self._pending_store = liststore
         self._treeview_pending.set_model(liststore)
-        self._treeview_pending.append_column(gtk.TreeViewColumn(_('Date'),
+        self._treeview_pending.append_column(gtk.TreeViewColumn(_i18n('Date'),
                                              gtk.CellRendererText(), text=1))
-        self._treeview_pending.append_column(gtk.TreeViewColumn(_('Committer'),
+        self._treeview_pending.append_column(gtk.TreeViewColumn(_i18n('Committer'),
                                              gtk.CellRendererText(), text=2))
-        self._treeview_pending.append_column(gtk.TreeViewColumn(_('Summary'),
+        self._treeview_pending.append_column(gtk.TreeViewColumn(_i18n('Summary'),
                                              gtk.CellRendererText(), text=3))
 
     def _construct_diff_view(self):
@@ -491,7 +492,7 @@
         #       decide that we really don't ever want to display it, we should
         #       actually remove it, and other references to it, along with the
         #       tests that it is set properly.
-        self._diff_label = gtk.Label(_('Diff for whole tree'))
+        self._diff_label = gtk.Label(_i18n('Diff for whole tree'))
         self._diff_label.set_alignment(0, 0)
         self._right_pane_table.set_row_spacing(self._right_pane_table_row, 0)
         self._add_to_right_table(self._diff_label, 1, False)
@@ -515,15 +516,16 @@
         self._file_message_text_view.set_accepts_tab(False)
         self._file_message_text_view.show()
 
-        self._file_message_expander = gtk.Expander(_('File commit message'))
+        self._file_message_expander = gtk.Expander(_i18n('File commit message'))
         self._file_message_expander.set_expanded(True)
         self._file_message_expander.add(scroller)
         self._add_to_right_table(self._file_message_expander, 1, False)
         self._file_message_expander.show()
 
     def _construct_global_message(self):
-        self._global_message_label = gtk.Label(_('Global Commit Message'))
-        self._global_message_label.set_markup(_('<b>Global Commit Message</b>'))
+        self._global_message_label = gtk.Label(_i18n('Global Commit Message'))
+        self._global_message_label.set_markup(
+            _i18n('<b>Global Commit Message</b>'))
         self._global_message_label.set_alignment(0, 0)
         self._right_pane_table.set_row_spacing(self._right_pane_table_row, 0)
         self._add_to_right_table(self._global_message_label, 1, False)
@@ -549,7 +551,7 @@
 
         if selection is not None:
             path, display_path = model.get(selection, 1, 3)
-            self._diff_label.set_text(_('Diff for ') + display_path)
+            self._diff_label.set_text(_i18n('Diff for ') + display_path)
             if path is None:
                 self._diff_view.show_diff(None)
             else:
@@ -596,13 +598,13 @@
         text_buffer = self._file_message_text_view.get_buffer()
         file_id, display_path, message = self._files_store.get(selection, 0, 3, 5)
         if file_id is None: # Whole tree
-            self._file_message_expander.set_label(_('File commit message'))
+            self._file_message_expander.set_label(_i18n('File commit message'))
             self._file_message_expander.set_expanded(False)
             self._file_message_expander.set_sensitive(False)
             text_buffer.set_text('')
             self._last_selected_file = None
         else:
-            self._file_message_expander.set_label(_('Commit message for ')
+            self._file_message_expander.set_label(_i18n('Commit message for ')
                                                   + display_path)
             self._file_message_expander.set_expanded(True)
             self._file_message_expander.set_sensitive(True)
@@ -647,8 +649,8 @@
 
         if message == '':
             response = self._question_dialog(
-                            _('Commit with an empty message?'),
-                            _('You can describe your commit intent in the message.'))
+                _i18n('Commit with an empty message?'),
+                _i18n('You can describe your commit intent in the message.'))
             if response == gtk.RESPONSE_NO:
                 # Kindly give focus to message area
                 self._global_message_text_view.grab_focus()
@@ -667,8 +669,8 @@
         #       files at this point.
         for path in self._wt.unknowns():
             response = self._question_dialog(
-                _("Commit with unknowns?"),
-                _("Unknown files exist in the working tree. Commit anyway?"))
+                _i18n("Commit with unknowns?"),
+                _i18n("Unknown files exist in the working tree. Commit anyway?"))
             if response == gtk.RESPONSE_NO:
                 return
             break
@@ -686,9 +688,9 @@
                        revprops=revprops)
         except errors.PointlessCommit:
             response = self._question_dialog(
-                                _('Commit with no changes?'),
-                                _('There are no changes in the working tree.'
-                                  ' Do you want to commit anyway?'))
+                _i18n('Commit with no changes?'),
+                _i18n('There are no changes in the working tree.'
+                      ' Do you want to commit anyway?'))
             if response == gtk.RESPONSE_YES:
                 rev_id = self._wt.commit(message,
                                allow_pointless=True,

=== modified file 'conflicts.py'
--- conflicts.py	2008-03-07 15:56:36 +0000
+++ conflicts.py	2008-05-05 18:16:46 +0000
@@ -26,6 +26,7 @@
 import gobject
 
 from bzrlib.config import GlobalConfig
+from bzrlib.plugins.gtk import _i18n
 
 from dialog import error_dialog, warning_dialog
 from errors import show_bzr_error
@@ -45,7 +46,7 @@
         # Create the widgets
         self._scrolledwindow = gtk.ScrolledWindow()
         self._treeview = gtk.TreeView()
-        self._label_diff3 = gtk.Label(_("External utility:"))
+        self._label_diff3 = gtk.Label(_i18n("External utility:"))
         self._entry_diff3 = gtk.Entry()
         self._image_diff3 = gtk.Image()
         self._button_diff3 = gtk.Button()
@@ -96,42 +97,42 @@
         if len(self.wt.conflicts()) == 0:
             self.model = gtk.ListStore(gobject.TYPE_STRING)
             self._treeview.set_model(self.model)
-            self._treeview.append_column(gtk.TreeViewColumn(_('Conflicts'),
+            self._treeview.append_column(gtk.TreeViewColumn(_i18n('Conflicts'),
                                          gtk.CellRendererText(), text=0))
             self._treeview.set_headers_visible(False)            
-            self.model.append([ _("No conflicts in working tree.") ])
+            self.model.append([ _i18n("No conflicts in working tree.") ])
             self._button_diff3.set_sensitive(False)
         else:
             self.model = gtk.ListStore(gobject.TYPE_STRING,
                                        gobject.TYPE_STRING,
                                        gobject.TYPE_STRING)
             self._treeview.set_model(self.model)
-            self._treeview.append_column(gtk.TreeViewColumn(_('Path'),
+            self._treeview.append_column(gtk.TreeViewColumn(_i18n('Path'),
                                          gtk.CellRendererText(), text=0))
-            self._treeview.append_column(gtk.TreeViewColumn(_('Type'),
+            self._treeview.append_column(gtk.TreeViewColumn(_i18n('Type'),
                                          gtk.CellRendererText(), text=1))
             self._treeview.set_search_column(0)
             for conflict in self.wt.conflicts():
                 if conflict.typestring == 'path conflict':
-                    t = _("path conflict")
+                    t = _i18n("path conflict")
                 elif conflict.typestring == 'contents conflict':
-                    t = _("contents conflict")
+                    t = _i18n("contents conflict")
                 elif conflict.typestring == 'text conflict':
-                    t = _("text conflict")
+                    t = _i18n("text conflict")
                 elif conflict.typestring == 'duplicate id':
-                    t = _("duplicate id")
+                    t = _i18n("duplicate id")
                 elif conflict.typestring == 'duplicate':
-                    t = _("duplicate")
+                    t = _i18n("duplicate")
                 elif conflict.typestring == 'parent loop':
-                    t = _("parent loop")
+                    t = _i18n("parent loop")
                 elif conflict.typestring == 'unversioned parent':
-                    t = _("unversioned parent")
+                    t = _i18n("unversioned parent")
                 elif conflict.typestring == 'missing parent':
-                    t = _("missing parent")
+                    t = _i18n("missing parent")
                 elif conflict.typestring == 'deleting parent':
-                    t = _("deleting parent")
+                    t = _i18n("deleting parent")
                 else:
-                    t = _("unknown type of conflict")
+                    t = _i18n("unknown type of conflict")
                 
                 self.model.append([ conflict.path, t, conflict.typestring ]) 
     
@@ -160,8 +161,8 @@
         self._set_diff3(self._entry_diff3.get_text())
         selected = self._get_selected_file()
         if selected is None:
-            error_dialog(_('No file was selected'),
-                         _('Please select a file from the list.'))
+            error_dialog(_i18n('No file was selected'),
+                         _i18n('Please select a file from the list.'))
             return
         elif self._get_selected_type() == 'text conflict':
             base = self.wt.abspath(selected) + '.BASE'
@@ -171,8 +172,8 @@
                 p = subprocess.Popen([ self._entry_diff3.get_text(), base, this, other ])
                 p.wait()
             except OSError, e:
-                warning_dialog(_('Call to external utility failed'), str(e))
+                warning_dialog(_i18n('Call to external utility failed'), str(e))
         else:
-            warning_dialog(_('Cannot resolve conflict'),
-                           _('Only conflicts on the text of files can be resolved with Olive at the moment. Content conflicts, on the structure of the tree, need to be resolved using the command line.'))
+            warning_dialog(_i18n('Cannot resolve conflict'),
+                           _i18n('Only conflicts on the text of files can be resolved with Olive at the moment. Content conflicts, on the structure of the tree, need to be resolved using the command line.'))
             return

=== modified file 'diff.py'
--- diff.py	2008-03-11 13:18:28 +0000
+++ diff.py	2008-05-22 02:33:40 +0000
@@ -41,6 +41,7 @@
 from bzrlib.errors import NoSuchFile
 from bzrlib.patches import parse_patches
 from bzrlib.trace import warning
+from bzrlib.plugins.gtk import _i18n
 from bzrlib.plugins.gtk.window import Window
 from dialog import error_dialog, info_dialog, warning_dialog
 
@@ -327,16 +328,16 @@
         """
         # The diffs of the  selected file: a scrollable source or
         # text view
+
+    def set_diff_text_sections(self, sections):
         self.diff_view = DiffFileView()
         self.diff_view.show()
         self.pack2(self.diff_view)
-        self.model.append(None, [ "Complete Diff", "" ])
-        self.diff_view._diffs[None] = ''.join(lines)
-        for patch in parse_patches(lines):
-            oldname = patch.oldname.split('\t')[0]
-            newname = patch.newname.split('\t')[0]
+        for oldname, newname, patch in sections:
+            self.diff_view._diffs[newname] = str(patch)
+            if newname is None:
+                newname = ''
             self.model.append(None, [oldname, newname])
-            self.diff_view._diffs[newname] = str(patch)
         self.diff_view.show_diff(None)
 
     def set_diff(self, rev_tree, parent_tree):
@@ -412,7 +413,7 @@
     differences between two revisions on a branch.
     """
 
-    def __init__(self, parent=None):
+    def __init__(self, parent=None, operations=None):
         Window.__init__(self, parent)
         self.set_border_width(0)
         self.set_title("bzrk diff")
@@ -423,36 +424,79 @@
         width = int(monitor.width * 0.66)
         height = int(monitor.height * 0.66)
         self.set_default_size(width, height)
-
-        self.construct()
-
-    def construct(self):
+        self.construct(operations)
+
+    def construct(self, operations):
         """Construct the window contents."""
         self.vbox = gtk.VBox()
         self.add(self.vbox)
         self.vbox.show()
-        hbox = self._get_button_bar()
+        hbox = self._get_button_bar(operations)
         if hbox is not None:
             self.vbox.pack_start(hbox, expand=False, fill=True)
         self.diff = DiffWidget()
         self.vbox.add(self.diff)
         self.diff.show_all()
 
-    def _get_button_bar(self):
+    def _get_button_bar(self, operations):
         """Return a button bar to use.
 
         :return: None, meaning that no button bar will be used.
         """
-        return None
-
-    def set_diff_text(self, description, lines):
-        """Set the diff from a text.
-
-        The diff must be in unified diff format, and will be parsed to
-        determine filenames.
-        """
-        self.diff.set_diff_text(lines)
-        self.set_title(description + " - bzrk diff")
+        if operations is None:
+            return None
+        hbox = gtk.HButtonBox()
+        hbox.set_layout(gtk.BUTTONBOX_START)
+        for title, method in operations:
+            merge_button = gtk.Button(title)
+            merge_button.show()
+            merge_button.set_relief(gtk.RELIEF_NONE)
+            merge_button.connect("clicked", method)
+            hbox.pack_start(merge_button, expand=False, fill=True)
+        hbox.show()
+        return hbox
+
+    def _get_merge_target(self):
+        d = gtk.FileChooserDialog('Merge branch', self,
+                                  gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER,
+                                  buttons=(gtk.STOCK_OK, gtk.RESPONSE_OK,
+                                           gtk.STOCK_CANCEL,
+                                           gtk.RESPONSE_CANCEL,))
+        try:
+            result = d.run()
+            if result != gtk.RESPONSE_OK:
+                raise SelectCancelled()
+            return d.get_current_folder_uri()
+        finally:
+            d.destroy()
+
+    def _merge_successful(self):
+        # No conflicts found.
+        info_dialog(_i18n('Merge successful'),
+                    _i18n('All changes applied successfully.'))
+
+    def _conflicts(self):
+        warning_dialog(_i18n('Conflicts encountered'),
+                       _i18n('Please resolve the conflicts manually'
+                             ' before committing.'))
+
+    def _handle_error(self, e):
+        error_dialog('Error', str(e))
+
+    def _get_save_path(self, basename):
+        d = gtk.FileChooserDialog('Save As', self,
+                                  gtk.FILE_CHOOSER_ACTION_SAVE,
+                                  buttons=(gtk.STOCK_OK, gtk.RESPONSE_OK,
+                                           gtk.STOCK_CANCEL,
+                                           gtk.RESPONSE_CANCEL,))
+        d.set_current_name(basename)
+        try:
+            result = d.run()
+            if result != gtk.RESPONSE_OK:
+                raise SelectCancelled()
+            return urlutils.local_path_from_url(d.get_uri())
+        finally:
+            d.destroy()
 
     def set_diff(self, description, rev_tree, parent_tree):
         """Set the differences showed by this window.
@@ -467,38 +511,64 @@
         self.diff.set_file(file_path)
 
 
-class MergeDirectiveWindow(DiffWindow):
-
-    def __init__(self, directive, path):
-        DiffWindow.__init__(self, None)
-        self._merge_target = None
+class DiffController(object):
+
+    def __init__(self, path, patch, window=None):
+        self.path = path
+        self.patch = patch
+        if window is None:
+            window = DiffWindow(operations=self._provide_operations())
+            self.initialize_window(window)
+        self.window = window
+
+    def initialize_window(self, window):
+        window.diff.set_diff_text_sections(self.get_diff_sections())
+        window.set_title(self.path + " - diff")
+
+    def get_diff_sections(self):
+        yield "Complete Diff", None, ''.join(self.patch)
+        for patch in parse_patches(self.patch):
+            oldname = patch.oldname.split('\t')[0]
+            newname = patch.newname.split('\t')[0]
+            yield oldname, newname, str(patch)
+
+    def perform_save(self, window):
+        try:
+            save_path = self.window._get_save_path(osutils.basename(self.path))
+        except SelectCancelled:
+            return
+        source = open(self.path, 'rb')
+        try:
+            target = open(save_path, 'wb')
+            try:
+                osutils.pumpfile(source, target)
+            finally:
+                target.close()
+        finally:
+            source.close()
+
+    def _provide_operations(self):
+        return [('Save', self.perform_save)]
+
+
+class MergeDirectiveController(DiffController):
+
+    def __init__(self, path, directive, window=None):
+        DiffController.__init__(self, path, directive.patch.splitlines(True),
+                                window)
         self.directive = directive
-        self.path = path
-
-    def _get_button_bar(self):
-        """The button bar has only the Merge button"""
-        merge_button = gtk.Button('Merge')
-        merge_button.show()
-        merge_button.set_relief(gtk.RELIEF_NONE)
-        merge_button.connect("clicked", self.perform_merge)
-
-        save_button = gtk.Button('Save')
-        save_button.show()
-        save_button.set_relief(gtk.RELIEF_NONE)
-        save_button.connect("clicked", self.perform_save)
-
-        hbox = gtk.HButtonBox()
-        hbox.set_layout(gtk.BUTTONBOX_START)
-        hbox.pack_start(merge_button, expand=False, fill=True)
-        hbox.pack_start(save_button, expand=False, fill=True)
-        hbox.show()
-        return hbox
+        self.merge_target = None
+
+    def _provide_operations(self):
+        return [('Merge', self.perform_merge), ('Save', self.perform_save)]
 
     def perform_merge(self, window):
-        try:
-            tree = self._get_merge_target()
-        except SelectCancelled:
-            return
+        if self.merge_target is None:
+            try:
+                self.merge_target = self.window._get_merge_target()
+            except SelectCancelled:
+                return
+        tree = workingtree.WorkingTree.open(self.merge_target)
         tree.lock_write()
         try:
             try:
@@ -509,64 +579,16 @@
                 conflict_count = merger.do_merge()
                 merger.set_pending()
                 if conflict_count == 0:
-                    # No conflicts found.
-                    info_dialog(_('Merge successful'),
-                                _('All changes applied successfully.'))
+                    self.window._merge_successful()
                 else:
+                    self.window._conflicts()
                     # There are conflicts to be resolved.
-                    warning_dialog(_('Conflicts encountered'),
-                                   _('Please resolve the conflicts manually'
-                                     ' before committing.'))
-                self.destroy()
+                self.window.destroy()
             except Exception, e:
-                error_dialog('Error', str(e))
+                self.window._handle_error(e)
         finally:
             tree.unlock()
 
-    def _get_merge_target(self):
-        if self._merge_target is not None:
-            return self._merge_target
-        d = gtk.FileChooserDialog('Merge branch', self,
-                                  gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER,
-                                  buttons=(gtk.STOCK_OK, gtk.RESPONSE_OK,
-                                           gtk.STOCK_CANCEL,
-                                           gtk.RESPONSE_CANCEL,))
-        try:
-            result = d.run()
-            if result != gtk.RESPONSE_OK:
-                raise SelectCancelled()
-            uri = d.get_current_folder_uri()
-        finally:
-            d.destroy()
-        return workingtree.WorkingTree.open(uri)
-
-    def perform_save(self, window):
-        d = gtk.FileChooserDialog('Save As', self,
-                                  gtk.FILE_CHOOSER_ACTION_SAVE,
-                                  buttons=(gtk.STOCK_OK, gtk.RESPONSE_OK,
-                                           gtk.STOCK_CANCEL,
-                                           gtk.RESPONSE_CANCEL,))
-        d.set_current_name(osutils.basename(self.path))
-        try:
-            try:
-                result = d.run()
-                if result != gtk.RESPONSE_OK:
-                    raise SelectCancelled()
-                uri = d.get_uri()
-            finally:
-                d.destroy()
-        except SelectCancelled:
-            return
-        source = open(self.path, 'rb')
-        try:
-            target = open(urlutils.local_path_from_url(uri), 'wb')
-            try:
-                target.write(source.read())
-            finally:
-                target.close()
-        finally:
-            source.close()
-
 
 def iter_changes_to_status(source, target):
     """Determine the differences between trees.

=== modified file 'errors.py'
--- errors.py	2007-02-03 14:19:44 +0000
+++ errors.py	2008-05-05 18:16:46 +0000
@@ -15,58 +15,61 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import bzrlib.errors as errors
+from bzrlib.plugins.gtk import _i18n
 from dialog import error_dialog
 
+
 def show_bzr_error(unbound):
     """Decorator that shows bazaar exceptions. """
     def convert(*args, **kwargs):
         try:
             unbound(*args, **kwargs)
         except errors.NotBranchError:
-            error_dialog(_('Directory is not a branch'),
-                         _('You can perform this action only in a branch.'))
+            error_dialog(_i18n('Directory is not a branch'),
+                         _i18n('You can perform this action only in a branch.'))
         except errors.LocalRequiresBoundBranch:
-            error_dialog(_('Directory is not a checkout'),
-                         _('You can perform local commit only on checkouts.'))
+            error_dialog(_i18n('Directory is not a checkout'),
+                         _i18n('You can perform local commit only on checkouts.'))
         except errors.PointlessCommit:
-            error_dialog(_('No changes to commit'),
-                         _('Try force commit if you want to commit anyway.'))
+            error_dialog(_i18n('No changes to commit'),
+                         _i18n('Try force commit if you want to commit anyway.'))
         except errors.ConflictsInTree:
-            error_dialog(_('Conflicts in tree'),
-                         _('You need to resolve the conflicts before committing.'))
+            error_dialog(_i18n('Conflicts in tree'),
+                         _i18n('You need to resolve the conflicts before committing.'))
         except errors.StrictCommitFailed:
-            error_dialog(_('Strict commit failed'),
-                         _('There are unknown files in the working tree.\nPlease add or delete them.'))
+            error_dialog(_i18n('Strict commit failed'),
+                         _i18n('There are unknown files in the working tree.\nPlease add or delete them.'))
         except errors.BoundBranchOutOfDate, errmsg:
-            error_dialog(_('Bound branch is out of date'),
-                         _('%s') % errmsg)
+            error_dialog(_i18n('Bound branch is out of date'),
+                         # FIXME: Really ? Internationalizing %s ?? --vila080505
+                         _i18n('%s') % errmsg)
         except errors.NotVersionedError:
-            error_dialog(_('File not versioned'),
-                         _('The selected file is not versioned.'))
+            error_dialog(_i18n('File not versioned'),
+                         _i18n('The selected file is not versioned.'))
         except errors.DivergedBranches:
-            error_dialog(_('Branches have been diverged'),
-                         _('You cannot push if branches have diverged. Use the\noverwrite option if you want to push anyway.'))
+            error_dialog(_i18n('Branches have been diverged'),
+                         _i18n('You cannot push if branches have diverged. Use the\noverwrite option if you want to push anyway.'))
         except errors.NoSuchFile:
-            error_dialog(_("No diff output"),
-                         _("The selected file hasn't changed."))
+            error_dialog(_i18n("No diff output"),
+                         _i18n("The selected file hasn't changed."))
         except errors.NoSuchRevision:
-                error_dialog(_('No such revision'),
-                             _("The revision you specified doesn't exist."))
+                error_dialog(_i18n('No such revision'),
+                             _i18n("The revision you specified doesn't exist."))
         except errors.FileExists:
-                error_dialog(_('Target already exists'),
-                             _("Target directory already exists. Please select another target."))
+                error_dialog(_i18n('Target already exists'),
+                             _i18n("Target directory already exists. Please select another target."))
         except errors.AlreadyBranchError, errmsg:
-            error_dialog(_('Directory is already a branch'),
-                         _('The current directory (%s) is already a branch.\nYou can start using it, or initialize another directory.') % errmsg)
+            error_dialog(_i18n('Directory is already a branch'),
+                         _i18n('The current directory (%s) is already a branch.\nYou can start using it, or initialize another directory.') % errmsg)
         except errors.BranchExistsWithoutWorkingTree, errmsg:
-            error_dialog(_('Branch without a working tree'),
-                         _('The current directory (%s)\nis a branch without a working tree.') % errmsg)
+            error_dialog(_i18n('Branch without a working tree'),
+                         _i18n('The current directory (%s)\nis a branch without a working tree.') % errmsg)
         except errors.BzrError, msg:
-            error_dialog(_('Unknown bzr error'), str(msg))
+            error_dialog(_i18n('Unknown bzr error'), str(msg))
         except errors.PermissionDenied:
-            error_dialog(_("Permission denied"), _("permission denied."))
+            error_dialog(_i18n("Permission denied"), _i18n("permission denied."))
         except Exception, msg:
-            error_dialog(_('Unknown error'), str(msg))
+            error_dialog(_i18n('Unknown error'), str(msg))
 
     convert.__doc__ = unbound.__doc__
     convert.__name__ = unbound.__name__

=== modified file 'genpot.sh'
--- genpot.sh	2007-08-13 10:08:10 +0000
+++ genpot.sh	2008-05-05 18:16:46 +0000
@@ -18,16 +18,26 @@
 
 # Generate translation template
 
-if [ -x po/olive-gtk.pot ]; then
-    rm po/olive-gtk.pot
-    touch po/olive-gtk.pot
-else
-    touch po/olive-gtk.pot
-fi
-xgettext -L python -o po/olive-gtk.pot olive-gtk
-xgettext -j -o po/olive-gtk.pot olive.glade
-xgettext -j -o po/olive-gtk.pot *.py
-cd olive/
-xgettext -j -o ../po/olive-gtk.pot *.py
-#cd viz
-#xgettext -j -o ../../../../po/olive-gtk.pot *.py
+if [ "$1" = "" ]; then
+    POT=po/olive-gtk.pot
+else
+    # Used for debugging
+    POT=$1 
+fi
+
+XGETTEXT="xgettext -o $POT"
+PY_XGETTEXT="$XGETTEXT -L python --from-code=ASCII --keyword=_i18n"
+
+if [ -x $POT ]; then
+    rm $POT
+    touch $POT
+else
+    touch $POT
+fi
+$PY_XGETTEXT olive-gtk
+$XGETTEXT -j olive.glade
+
+for d in . annotate branchview olive preferences viz ;
+do
+   $PY_XGETTEXT -j $d/*.py
+done

=== modified file 'initialize.py'
--- initialize.py	2007-04-06 17:48:23 +0000
+++ initialize.py	2008-05-05 18:16:46 +0000
@@ -30,6 +30,7 @@
 from bzrlib import bzrdir
 from bzrlib import transport
 import bzrlib.errors as errors
+from bzrlib.plugins.gtk import _i18n
 
 class InitDialog(gtk.Dialog):
     """ Initialize dialog. """
@@ -44,10 +45,10 @@
         self.path = path
         
         # Create the widgets
-        self._button_init = gtk.Button(_("_Initialize"), use_underline=True)
-        self._label_question = gtk.Label(_("Which directory do you want to initialize?"))
-        self._radio_current = gtk.RadioButton(None, _("Current directory"))
-        self._radio_custom = gtk.RadioButton(self._radio_current, _("Create a new directory with the name:"))
+        self._button_init = gtk.Button(_i18n("_Initialize"), use_underline=True)
+        self._label_question = gtk.Label(_i18n("Which directory do you want to initialize?"))
+        self._radio_current = gtk.RadioButton(None, _i18n("Current directory"))
+        self._radio_custom = gtk.RadioButton(self._radio_current, _i18n("Create a new directory with the name:"))
         self._entry_custom = gtk.Entry()
         self._hbox_custom = gtk.HBox()
         
@@ -82,8 +83,8 @@
     @show_bzr_error
     def _on_init_clicked(self, widget):
         if self._radio_custom.get_active() and len(self._entry_custom.get_text()) == 0:
-            error_dialog(_("Directory name not specified"),
-                         _("You should specify a new directory name."))
+            error_dialog(_i18n("Directory name not specified"),
+                         _i18n("You should specify a new directory name."))
             return
         
         if self._radio_current.get_active():

=== modified file 'merge.py'
--- merge.py	2007-09-11 10:17:33 +0000
+++ merge.py	2008-05-05 18:16:46 +0000
@@ -27,6 +27,7 @@
 
 from bzrlib.branch import Branch
 import bzrlib.errors as errors
+from bzrlib.plugins.gtk import _i18n
 
 from dialog import error_dialog, info_dialog, warning_dialog
 from errors import show_bzr_error
@@ -65,8 +66,8 @@
     def merge(self, widget):
         branch = self.entry.get_text()
         if branch == "":
-            error_dialog(_('Branch not given'),
-                         _('Please specify a branch to merge from.'))
+            error_dialog(_i18n('Branch not given'),
+                         _i18n('Please specify a branch to merge from.'))
             return
 
         other_branch = Branch.open_containing(branch)[0]
@@ -74,18 +75,18 @@
         try:
             conflicts = self.wt.merge_from_branch(other_branch)
         except errors.BzrCommandError, errmsg:
-            error_dialog(_('Bazaar command error'), str(errmsg))
+            error_dialog(_i18n('Bazaar command error'), str(errmsg))
             return
         
         self.close()
         if conflicts == 0:
             # No conflicts found.
-            info_dialog(_('Merge successful'),
-                        _('All changes applied successfully.'))
+            info_dialog(_i18n('Merge successful'),
+                        _i18n('All changes applied successfully.'))
         else:
             # There are conflicts to be resolved.
-            warning_dialog(_('Conflicts encountered'),
-                           _('Please resolve the conflicts manually before committing.'))
+            warning_dialog(_i18n('Conflicts encountered'),
+                           _i18n('Please resolve the conflicts manually before committing.'))
     
     def open(self, widget):
         fcd = gtk.FileChooserDialog(title="Please select a folder",

=== modified file 'nautilus-bzr.py'
--- nautilus-bzr.py	2008-04-04 01:46:01 +0000
+++ nautilus-bzr.py	2008-05-05 18:16:46 +0000
@@ -19,7 +19,7 @@
 from bzrlib.plugin import load_plugins
 load_plugins()
 
-from bzrlib.plugins.gtk import cmd_visualise, cmd_gannotate
+from bzrlib.plugins.gtk import _i18n, cmd_visualise, cmd_gannotate
 
 class BzrExtension(nautilus.MenuProvider, nautilus.ColumnProvider, nautilus.InfoProvider):
     def __init__(self):

=== added file 'olive-gtk.1'
--- olive-gtk.1	1970-01-01 00:00:00 +0000
+++ olive-gtk.1	2008-05-01 12:55:33 +0000
@@ -0,0 +1,15 @@
+.TH OLIVE-GTK 1 "April 24, 2007"
+.SH NAME
+olive-gtk \- GTK+ frontend for Bazaar
+.SH SYNOPSIS
+.B olive-gtk
+.SH DESCRIPTION
+Olive aims to be a full-featured graphical frontend for the Bazaar (bzr)
+source code management tool.
+.SH SEE ALSO
+.BR bzr (1).
+.SH AUTHOR
+\fBolive-gtk\fP was written by Szilveszter Farkas <szilveszter.farkas@gmail.com>
+.PP
+This manual page was written by Chris Lamb <chris@chris-lamb.co.uk>,
+for the Debian project (but may be used by others).

=== modified file 'olive/__init__.py'
--- olive/__init__.py	2008-03-30 14:12:10 +0000
+++ olive/__init__.py	2008-05-05 18:16:46 +0000
@@ -1,5 +1,4 @@
-﻿#!/usr/bin/python
-# -*- coding: UTF-8 -*-
+ #!/usr/bin/python
 
 # Copyright (C) 2006 by Szilveszter Farkas (Phanatic) <szilveszter.farkas@gmail.com>
 #
@@ -42,6 +41,7 @@
 from bzrlib.ui import ui_factory
 from bzrlib.workingtree import WorkingTree
 
+from bzrlib.plugins.gtk import _i18n
 from bzrlib.plugins.gtk.dialog import error_dialog, info_dialog, warning_dialog
 from bzrlib.plugins.gtk.errors import show_bzr_error
 from guifiles import GLADEFILENAME
@@ -69,9 +69,9 @@
 
     # Set version
     dialog.set_version(__version__)
-    dialog.set_authors([ _("Lead Developer:"),
+    dialog.set_authors([ _i18n("Lead Developer:"),
 			 "Szilveszter Farkas <szilveszter.farkas@gmail.com>",
-			 _("Contributors:"),
+			 _i18n("Contributors:"),
 			 "Jelmer Vernooij <jelmer@samba.org>",
 			 "Mateusz Korniak <mateusz.korniak@ant.gliwice.pl>",
 			 "Gary van der Merwe <garyvdm@gmail.com>" ])
@@ -537,8 +537,8 @@
         from bzrlib.plugins.gtk.merge import MergeDialog
         
         if self.check_for_changes():
-            error_dialog(_('There are local changes in the branch'),
-                         _('Please commit or revert the changes before merging.'))
+            error_dialog(_i18n('There are local changes in the branch'),
+                         _i18n('Please commit or revert the changes before merging.'))
         else:
             parent_branch_path = self.wt.branch.get_parent()
             merge = MergeDialog(self.wt, self.wtpath,default_branch_path=parent_branch_path )
@@ -553,8 +553,8 @@
         local_branch = self.wt.branch
         parent_branch_path = local_branch.get_parent()
         if parent_branch_path is None:
-            error_dialog(_('Parent location is unknown'),
-                         _('Cannot determine missing revisions if no parent location is known.'))
+            error_dialog(_i18n('Parent location is unknown'),
+                         _i18n('Cannot determine missing revisions if no parent location is known.'))
             return
         
         parent_branch = Branch.open(parent_branch_path)
@@ -576,32 +576,32 @@
             
             dlg_txt = ""
             if local_extra:
-                dlg_txt += _('%d local extra revision(s). \n') % (len(local_extra),) 
+                dlg_txt += _i18n('%d local extra revision(s). \n') % (len(local_extra),) 
                 ## NOTE: We do not want such ugly info about missing revisions
                 ##       Revision Browser should be used there
                 ## max_revisions = 10
                 ## for log_revision in iter_log_revisions(local_extra, local_branch.repository, verbose=1):
                 ##    dlg_txt += log_revision_one_line_text(log_revision)
                 ##    if max_revisions <= 0:
-                ##        dlg_txt += _("more ... \n")
+                ##        dlg_txt += _i18n("more ... \n")
                 ##        break
                 ## max_revisions -= 1
             ## dlg_txt += "\n"
             if remote_extra:
-                dlg_txt += _('%d local missing revision(s).\n') % (len(remote_extra),) 
+                dlg_txt += _i18n('%d local missing revision(s).\n') % (len(remote_extra),) 
                 ## max_revisions = 10
                 ## for log_revision in iter_log_revisions(remote_extra, parent_branch.repository, verbose=1):
                 ##    dlg_txt += log_revision_one_line_text(log_revision)
                 ##    if max_revisions <= 0:
-                ##        dlg_txt += _("more ... \n")
+                ##        dlg_txt += _i18n("more ... \n")
                 ##        break
                 ##    max_revisions -= 1
                 
-            info_dialog(_('There are missing revisions'),
+            info_dialog(_i18n('There are missing revisions'),
                         dlg_txt)
         else:
-            info_dialog(_('Local branch up to date'),
-                        _('There are no missing revisions.'))
+            info_dialog(_i18n('Local branch up to date'),
+                        _i18n('There are no missing revisions.'))
 
     @show_bzr_error
     def on_menuitem_branch_pull_activate(self, widget):
@@ -610,8 +610,8 @@
 
         location = branch_to.get_parent()
         if location is None:
-            error_dialog(_('Parent location is unknown'),
-                                     _('Pulling is not possible until there is a parent location.'))
+            error_dialog(_i18n('Parent location is unknown'),
+                                     _i18n('Pulling is not possible until there is a parent location.'))
             return
 
         branch_from = Branch.open(location)
@@ -621,7 +621,7 @@
 
         ret = branch_to.pull(branch_from)
         
-        info_dialog(_('Pull successful'), _('%d revision(s) pulled.') % ret)
+        info_dialog(_i18n('Pull successful'), _i18n('%d revision(s) pulled.') % ret)
         
     @show_bzr_error
     def on_menuitem_branch_update_activate(self, widget):
@@ -630,9 +630,9 @@
         ret = self.wt.update()
         conflicts = self.wt.conflicts()
         if conflicts:
-            info_dialog(_('Update successful but conflicts generated'), _('Number of conflicts generated: %d.') % (len(conflicts),) )
+            info_dialog(_i18n('Update successful but conflicts generated'), _i18n('Number of conflicts generated: %d.') % (len(conflicts),) )
         else:
-            info_dialog(_('Update successful'), _('No conflicts generated.') )
+            info_dialog(_i18n('Update successful'), _i18n('No conflicts generated.') )
     
     def on_menuitem_branch_push_activate(self, widget):
         """ Branch/Push... menu handler. """
@@ -646,11 +646,11 @@
         """ Branch/Revert all changes menu handler. """
         ret = self.wt.revert([])
         if ret:
-            warning_dialog(_('Conflicts detected'),
-                           _('Please have a look at the working tree before continuing.'))
+            warning_dialog(_i18n('Conflicts detected'),
+                           _i18n('Please have a look at the working tree before continuing.'))
         else:
-            info_dialog(_('Revert successful'),
-                        _('All files reverted to last revision.'))
+            info_dialog(_i18n('Revert successful'),
+                        _i18n('All files reverted to last revision.'))
         self.refresh_right()
     
     def on_menuitem_branch_status_activate(self, widget):
@@ -685,8 +685,8 @@
     def on_menuitem_file_annotate_activate(self, widget):
         """ File/Annotate... menu handler. """
         if self.get_selected_right() is None:
-            error_dialog(_('No file was selected'),
-                         _('Please select a file from the list.'))
+            error_dialog(_i18n('No file was selected'),
+                         _i18n('Please select a file from the list.'))
             return
         
         branch = self.wt.branch
@@ -705,12 +705,12 @@
     def on_menuitem_file_bookmark_activate(self, widget):
         """ File/Bookmark current directory menu handler. """
         if self.pref.add_bookmark(self.path):
-            info_dialog(_('Bookmark successfully added'),
-                        _('The current directory was bookmarked. You can reach\nit by selecting it from the left panel.'))
+            info_dialog(_i18n('Bookmark successfully added'),
+                        _i18n('The current directory was bookmarked. You can reach\nit by selecting it from the left panel.'))
             self.pref.write()
         else:
-            warning_dialog(_('Location already bookmarked'),
-                           _('The current directory is already bookmarked.\nSee the left panel for reference.'))
+            warning_dialog(_i18n('Location already bookmarked'),
+                           _i18n('The current directory is already bookmarked.\nSee the left panel for reference.'))
         
         self.refresh_left()
     
@@ -940,14 +940,14 @@
         bookmarks = self.pref.get_bookmarks()
         
         # Add them to the TreeStore
-        titer = treestore.append(None, [_('Bookmarks'), None])
+        titer = treestore.append(None, [_i18n('Bookmarks'), None])
         for item in bookmarks:
             title = self.pref.get_bookmark_title(item)
             treestore.append(titer, [title, item])
         
         # Create the column and add it to the TreeView
         self.treeview_left.set_model(treestore)
-        tvcolumn_bookmark = gtk.TreeViewColumn(_('Bookmark'))
+        tvcolumn_bookmark = gtk.TreeViewColumn(_i18n('Bookmark'))
         self.treeview_left.append_column(tvcolumn_bookmark)
         
         # Set up the cells
@@ -1047,19 +1047,19 @@
                     self.wt.unlock()
             
             if status == 'renamed':
-                st = _('renamed')
+                st = _i18n('renamed')
             elif status == 'removed':
-                st = _('removed')
+                st = _i18n('removed')
             elif status == 'added':
-                st = _('added')
+                st = _i18n('added')
             elif status == 'modified':
-                st = _('modified')
+                st = _i18n('modified')
             elif status == 'unchanged':
-                st = _('unchanged')
+                st = _i18n('unchanged')
             elif status == 'ignored':
-                st = _('ignored')
+                st = _i18n('ignored')
             else:
-                st = _('unknown')
+                st = _i18n('unknown')
             
             try:
                 statinfo = os.stat(self.path + os.sep + item)
@@ -1081,10 +1081,10 @@
         
         # Create the columns and add them to the TreeView
         self.treeview_right.set_model(liststore)
-        self._tvcolumn_filename = gtk.TreeViewColumn(_('Filename'))
-        self._tvcolumn_status = gtk.TreeViewColumn(_('Status'))
-        self._tvcolumn_size = gtk.TreeViewColumn(_('Size'))
-        self._tvcolumn_mtime = gtk.TreeViewColumn(_('Last modified'))
+        self._tvcolumn_filename = gtk.TreeViewColumn(_i18n('Filename'))
+        self._tvcolumn_status = gtk.TreeViewColumn(_i18n('Status'))
+        self._tvcolumn_size = gtk.TreeViewColumn(_i18n('Size'))
+        self._tvcolumn_mtime = gtk.TreeViewColumn(_i18n('Last modified'))
         self.treeview_right.append_column(self._tvcolumn_filename)
         self.treeview_right.append_column(self._tvcolumn_status)
         self.treeview_right.append_column(self._tvcolumn_size)
@@ -1238,7 +1238,7 @@
         bookmarks = self.pref.get_bookmarks()
 
         # Add them to the TreeStore
-        titer = treestore.append(None, [_('Bookmarks'), None])
+        titer = treestore.append(None, [_i18n('Bookmarks'), None])
         for item in bookmarks:
             title = self.pref.get_bookmark_title(item)
             treestore.append(titer, [title, item])
@@ -1352,21 +1352,21 @@
                         self.wt.unlock()
                 
                 if status == 'renamed':
-                    st = _('renamed')
+                    st = _i18n('renamed')
                 elif status == 'removed':
-                    st = _('removed')
+                    st = _i18n('removed')
                 elif status == 'added':
-                    st = _('added')
+                    st = _i18n('added')
                 elif status == 'modified':
-                    st = _('modified')
+                    st = _i18n('modified')
                 elif status == 'unchanged':
-                    st = _('unchanged')
+                    st = _i18n('unchanged')
                 elif status == 'ignored':
-                    st = _('ignored')
+                    st = _i18n('ignored')
                     if not ignored_files:
                         continue
                 else:
-                    st = _('unknown')
+                    st = _i18n('unknown')
                 
                 try:
                     statinfo = os.stat(self.path + os.sep + item)

=== modified file 'olive/add.py'
--- olive/add.py	2007-02-03 14:18:57 +0000
+++ olive/add.py	2008-05-05 18:16:46 +0000
@@ -28,6 +28,7 @@
 import bzrlib.add
 import bzrlib.errors as errors
 
+from bzrlib.plugins.gtk import _i18n
 from bzrlib.plugins.gtk.dialog import error_dialog
 from guifiles import GLADEFILENAME
 
@@ -64,8 +65,8 @@
             filename = self.selected
             
             if filename is None:
-                error_dialog(_('No file was selected'),
-                             _('Please select a file from the list,\nor choose the other option.'))
+                error_dialog(_i18n('No file was selected'),
+                             _i18n('Please select a file from the list,\nor choose the other option.'))
                 return
             
             fullpath = self.wt.abspath(os.path.join(self.wtpath, filename))
@@ -73,8 +74,8 @@
             try:
                 bzrlib.add.smart_add([fullpath])
             except errors.NotBranchError:
-                error_dialog(_('Directory is not a branch'),
-                             _('You can perform this action only in a branch.'))
+                error_dialog(_i18n('Directory is not a branch'),
+                             _i18n('You can perform this action only in a branch.'))
                 return
         elif radio_unknown.get_active():
             # Add unknown files recursively
@@ -83,8 +84,8 @@
             try:
                 bzrlib.add.smart_add([fullpath], True)
             except errors.NotBranchError:
-                error_dialog(_('Directory is not a branch'),
-                             _('You can perform this action only in a branch.'))
+                error_dialog(_i18n('Directory is not a branch'),
+                             _i18n('You can perform this action only in a branch.'))
                 return
         
         self.close()

=== modified file 'olive/bookmark.py'
--- olive/bookmark.py	2007-02-03 14:18:57 +0000
+++ olive/bookmark.py	2008-05-05 18:16:46 +0000
@@ -23,6 +23,7 @@
 import gtk
 
 from olive import Preferences
+from bzrlib.plugins.gtk import _i18n
 from bzrlib.plugins.gtk.dialog import error_dialog
 
 
@@ -42,8 +43,8 @@
         self.selected = selected
         
         # Create widgets
-        self._label_location = gtk.Label(_("Location:"))
-        self._label_title = gtk.Label(_("Title:"))
+        self._label_location = gtk.Label(_i18n("Location:"))
+        self._label_title = gtk.Label(_i18n("Title:"))
         self._entry_location = gtk.Entry()
         self._entry_title = gtk.Entry()
         self._button_save = gtk.Button(stock=gtk.STOCK_SAVE)
@@ -78,8 +79,8 @@
     def _on_save_clicked(self, button):
         """ Save button clicked handler. """
         if self._entry_title.get_text() == '':
-            error_dialog(_('No title given'),
-                         _('Please specify a title to continue.'))
+            error_dialog(_i18n('No title given'),
+                         _i18n('Please specify a title to continue.'))
             return
         
         self.pref.set_bookmark_title(self._entry_location.get_text(),

=== modified file 'olive/guifiles.py'
--- olive/guifiles.py	2008-03-03 17:05:53 +0000
+++ olive/guifiles.py	2008-05-05 18:16:46 +0000
@@ -17,6 +17,7 @@
 import os
 import sys
 
+from bzrlib.plugins.gtk import _i18n
 
 GLADEFILENAMES = ["/usr/share/olive/olive.glade",
                   "/usr/local/share/olive/olive.glade",
@@ -44,7 +45,7 @@
 
 if GLADEFILENAME is None:
     # Fail
-    print _('Glade file cannot be found.')
+    print _i18n('Glade file cannot be found.')
     sys.exit(1)
 
 UIFILEDIR = os.path.dirname(GLADEFILENAME)
@@ -54,7 +55,7 @@
 
 if not os.path.isfile(UIFILENAME):
     # Fail
-    print _('UI description file cannot be found.')
+    print _i18n('UI description file cannot be found.')
     sys.exit(1)
 
 

=== modified file 'olive/info.py'
--- olive/info.py	2007-05-17 16:12:27 +0000
+++ olive/info.py	2008-05-05 18:16:46 +0000
@@ -25,6 +25,7 @@
 
 import bzrlib.errors as errors
 
+from bzrlib.plugins.gtk import _i18n
 from bzrlib.plugins.gtk.dialog import error_dialog
 from guifiles import GLADEFILENAME
 
@@ -553,8 +554,8 @@
     def display(self):
         """ Display the Informations window. """
         if self.notbranch:
-            error_dialog(_('Directory is not a branch'),
-                         _('You can perform this action only in a branch.'))
+            error_dialog(_i18n('Directory is not a branch'),
+                         _i18n('You can perform this action only in a branch.'))
             self.close()
         else:
             self.window.show()

=== modified file 'olive/menu.py'
--- olive/menu.py	2008-05-01 13:11:23 +0000
+++ olive/menu.py	2008-05-05 18:18:08 +0000
@@ -30,6 +30,7 @@
 import bzrlib.errors as errors
 from bzrlib.workingtree import WorkingTree
 
+from bzrlib.plugins.gtk import _i18n
 from bzrlib.plugins.gtk.dialog import error_dialog, info_dialog, question_dialog, warning_dialog
 from bzrlib.plugins.gtk.errors import show_bzr_error
 from bzrlib.plugins.gtk.annotate.gannotate import GAnnotateWindow
@@ -59,76 +60,76 @@
         
         self.actiongroup = gtk.ActionGroup('context')
         self.actiongroup.add_actions([('add', gtk.STOCK_ADD,
-                                       _('Add'), None,
-                                       _('Add the selected file'),
+                                       _i18n('Add'), None,
+                                       _i18n('Add the selected file'),
                                        self.add_file),
                                       ('remove', gtk.STOCK_REMOVE,
-                                       _('Remove'), None,
-                                       _('Remove the selected file'),
+                                       _i18n('Remove'), None,
+                                       _i18n('Remove the selected file'),
                                        self.remove_file),
                                       ('remove_and_delete', gtk.STOCK_REMOVE,
-                                       _('Remove and delete'), None,
-                                       _('Remove the selected file/dir and delete from disk'),
+                                       _i18n('Remove and delete'), None,
+                                       _i18n('Remove the selected file/dir and delete from disk'),
                                        self.remove_and_delete_file),
                                       ('rename', None,
-                                       _('Rename'), None,
-                                       _('Rename the selected file'),
+                                       _i18n('Rename'), None,
+                                       _i18n('Rename the selected file'),
                                        self.rename_file),
                                       ('open', gtk.STOCK_OPEN,
-                                       _('Open'), None,
-                                       _('Open the selected file'),
+                                       _i18n('Open'), None,
+                                       _i18n('Open the selected file'),
                                        self.open_file),
                                       ('revert', None,
-                                       _('Revert'), None,
-                                       _('Revert the changes'),
+                                       _i18n('Revert'), None,
+                                       _i18n('Revert the changes'),
                                        self.revert),
                                       ('commit', None,
-                                       _('Commit'), None,
-                                       _('Commit the changes'),
+                                       _i18n('Commit'), None,
+                                       _i18n('Commit the changes'),
                                        self.commit),
                                       ('annotate', None,
-                                       _('Annotate'), None,
-                                       _('Annotate the selected file'),
+                                       _i18n('Annotate'), None,
+                                       _i18n('Annotate the selected file'),
                                        self.annotate),
                                       ('diff', None,
-                                       _('Diff'), None,
-                                       _('Show the diff of the file'),
+                                       _i18n('Diff'), None,
+                                       _i18n('Show the diff of the file'),
                                        self.diff),
                                       ('bookmark', None,
-                                       _('Bookmark'), None,
-                                       _('Bookmark current location'),
+                                       _i18n('Bookmark'), None,
+                                       _i18n('Bookmark current location'),
                                        self.bookmark),
                                       ('edit_bookmark', gtk.STOCK_EDIT,
-                                       _('Edit'), None,
-                                       _('Edit the selected bookmark'),
+                                       _i18n('Edit'), None,
+                                       _i18n('Edit the selected bookmark'),
                                        self.edit_bookmark),
                                       ('remove_bookmark', gtk.STOCK_REMOVE,
-                                       _('Remove'), None,
-                                       _('Remove the selected bookmark'),
+                                       _i18n('Remove'), None,
+                                       _i18n('Remove the selected bookmark'),
                                        self.remove_bookmark),
                                       ('open_folder', gtk.STOCK_OPEN,
-                                       _('Open Folder'), None,
-                                       _('Open bookmark folder in Nautilus'),
+                                       _i18n('Open Folder'), None,
+                                       _i18n('Open bookmark folder in Nautilus'),
                                        self.open_folder),
                                       ('diff_selected', None,
-                                       _('Selected...'), None,
-                                       _('Show the differences of the selected file'),
+                                       _i18n('Selected...'), None,
+                                       _i18n('Show the differences of the selected file'),
                                        self.diff_selected),
                                       ('diff_all', None,
-                                       _('All...'), None,
-                                       _('Show the differences of all files'),
+                                       _i18n('All...'), None,
+                                       _i18n('Show the differences of all files'),
                                        self.diff_all),
                                       ('view_remote', None,
-                                       _('View contents'), None,
-                                       _('View the contents of the file in a builtin viewer'),
+                                       _i18n('View contents'), None,
+                                       _i18n('View the contents of the file in a builtin viewer'),
                                        self.view_remote),
                                       ('diff_remote', None,
-                                       _('Show differences'), None,
-                                       _('Show the differences between two revisions of the file'),
+                                       _i18n('Show differences'), None,
+                                       _i18n('Show the differences between two revisions of the file'),
                                        self.diff_remote),
                                       ('revert_remote', None,
-                                       _('Revert to this revision'), None,
-                                       _('Revert the selected file to the selected revision'),
+                                       _i18n('Revert to this revision'), None,
+                                       _i18n('Revert the selected file to the selected revision'),
                                        self.revert_remote)
                                      ])
         
@@ -174,8 +175,8 @@
         filename = self.selected
             
         if filename is None:
-            error_dialog(_('No file was selected'),
-                         _('Please select a file from the list,\nor choose the other option.'))
+            error_dialog(_i18n('No file was selected'),
+                         _i18n('Please select a file from the list,\nor choose the other option.'))
             return
         
         bzrlib.add.smart_add([os.path.join(directory, filename)])
@@ -187,8 +188,8 @@
         filename = self.selected
         
         if filename is None:
-            error_dialog(_('No file was selected'),
-                         _('Please select a file from the list.'))
+            error_dialog(_i18n('No file was selected'),
+                         _i18n('Please select a file from the list.'))
             return
         
         wt, path = WorkingTree.open_containing(os.path.join(directory, filename))
@@ -214,8 +215,8 @@
         filename = self.selected
         
         if filename is None:
-            error_dialog(_('No file was selected'),
-                         _('Please select a file from the list,\nor choose the other option.'))
+            error_dialog(_i18n('No file was selected'),
+                         _i18n('Please select a file from the list,\nor choose the other option.'))
             return
         
         wt, path = WorkingTree.open_containing(os.path.join(directory, filename))
@@ -224,7 +225,7 @@
         if delete_on_disk:
             abs_filename = os.path.join(directory,filename)
             if os.path.isdir(abs_filename):
-                response = question_dialog(_('Delete directory with all directories below ?'), abs_filename )
+                response = question_dialog(_i18n('Delete directory with all directories below ?'), abs_filename )
                 if response == gtk.RESPONSE_YES:
                     shutil.rmtree(abs_filename)
             else:
@@ -250,8 +251,8 @@
         filename = self.selected
         
         if filename is None:
-            error_dialog(_('No file was selected'),
-                         _('Please select a file from the list,\nor choose the other option.'))
+            error_dialog(_i18n('No file was selected'),
+                         _i18n('Please select a file from the list,\nor choose the other option.'))
             return
 
         if filename == '..':
@@ -271,11 +272,11 @@
         wt, path = WorkingTree.open_containing(self.path)
         ret = wt.revert([os.path.join(path, self.selected)])
         if ret:
-            warning_dialog(_('Conflicts detected'),
-                           _('Please have a look at the working tree before continuing.'))
+            warning_dialog(_i18n('Conflicts detected'),
+                           _i18n('Please have a look at the working tree before continuing.'))
         else:
-            info_dialog(_('Revert successful'),
-                        _('All files reverted to last revision.'))
+            info_dialog(_i18n('Revert successful'),
+                        _i18n('All files reverted to last revision.'))
         self.app.refresh_right()       
     
     def commit(self, action):
@@ -315,12 +316,12 @@
     def bookmark(self, action):
         """ Right context menu -> Bookmark """
         if self.pref.add_bookmark(self.path):
-            info_dialog(_('Bookmark successfully added'),
-                        _('The current directory was bookmarked. You can reach\nit by selecting it from the left panel.'))
+            info_dialog(_i18n('Bookmark successfully added'),
+                        _i18n('The current directory was bookmarked. You can reach\nit by selecting it from the left panel.'))
             self.pref.write()
         else:
-            warning_dialog(_('Location already bookmarked'),
-                           _('The current directory is already bookmarked.\nSee the left panel for reference.'))
+            warning_dialog(_i18n('Location already bookmarked'),
+                           _i18n('The current directory is already bookmarked.\nSee the left panel for reference.'))
         
         self.app.refresh_left()
 

=== modified file 'olive/mkdir.py'
--- olive/mkdir.py	2007-02-03 15:24:48 +0000
+++ olive/mkdir.py	2008-05-05 18:16:46 +0000
@@ -27,6 +27,7 @@
 
 import bzrlib.errors as errors
 
+from bzrlib.plugins.gtk import _i18n
 from bzrlib.plugins.gtk.dialog import error_dialog, warning_dialog
 from guifiles import GLADEFILENAME
 
@@ -64,8 +65,8 @@
         dirname = entry.get_text()
         
         if dirname == "":
-            error_dialog(_('No directory name given'),
-                         _('Please specify a desired name for the new directory.'))
+            error_dialog(_i18n('No directory name given'),
+                         _i18n('Please specify a desired name for the new directory.'))
             return
         
         if checkbox.get_active():
@@ -76,8 +77,8 @@
                 self.wt.add([os.path.join(self.wtpath, dirname)])
             except OSError, e:
                 if e.errno == 17:
-                    error_dialog(_('Directory already exists'),
-                                 _('Please specify another name to continue.'))
+                    error_dialog(_i18n('Directory already exists'),
+                                 _i18n('Please specify another name to continue.'))
                 else:
                     raise
         else:
@@ -86,8 +87,8 @@
                 os.mkdir(os.path.join(self.wt.basedir, self.wtpath, dirname))
             except OSError, e:
                 if e.errno == 17:
-                    error_dialog(_('Directory already exists'),
-                                 _('Please specify another name to continue.'))
+                    error_dialog(_i18n('Directory already exists'),
+                                 _i18n('Please specify another name to continue.'))
                     return
 
         self.close()

=== modified file 'olive/move.py'
--- olive/move.py	2007-02-03 14:18:57 +0000
+++ olive/move.py	2008-05-05 18:16:46 +0000
@@ -29,6 +29,7 @@
 import bzrlib.errors as errors
 from bzrlib.workingtree import WorkingTree
 
+from bzrlib.plugins.gtk import _i18n
 from bzrlib.plugins.gtk.dialog import error_dialog
 from errors import show_bzr_error
 from guifiles import GLADEFILENAME
@@ -76,8 +77,8 @@
         filename = self.selected
             
         if filename is None:
-            error_dialog(_('No file was selected'),
-                         _('Please select a file from the list to proceed.'))
+            error_dialog(_i18n('No file was selected'),
+                         _i18n('Please select a file from the list to proceed.'))
             return
         
         source = os.path.join(self.wtpath, filename)
@@ -86,8 +87,8 @@
         wt1, path1 = WorkingTree.open_containing(self.wt.abspath(source))
         wt2, path2 = WorkingTree.open_containing(destination)
         if wt1.basedir != wt2.basedir:
-            error_dialog(_('Not the same branch'),
-                         _('The destination is not in the same branch.'))
+            error_dialog(_i18n('Not the same branch'),
+                         _i18n('The destination is not in the same branch.'))
             return
 
         wt1.move([source], wt1.relpath(destination))

=== modified file 'olive/remove.py'
--- olive/remove.py	2007-02-03 14:18:57 +0000
+++ olive/remove.py	2008-05-05 18:16:46 +0000
@@ -27,6 +27,7 @@
 
 import bzrlib.errors as errors
 
+from bzrlib.plugins.gtk import _i18n
 from bzrlib.plugins.gtk.dialog import error_dialog, warning_dialog
 from guifiles import GLADEFILENAME
 
@@ -64,8 +65,8 @@
             filename = self.selected
             
             if filename is None:
-                error_dialog(_('No file was selected'),
-                             _('Please select a file from the list,\nor choose the other option.'))
+                error_dialog(_i18n('No file was selected'),
+                             _i18n('Please select a file from the list,\nor choose the other option.'))
                 return
             
             fullpath = self.wt.abspath(os.path.join(self.wtpath, filename))
@@ -76,8 +77,8 @@
             added = self.wt.changes_from(self.wt.basis_tree()).added
             file_list = sorted([f[0] for f in added], reverse=True)
             if len(file_list) == 0:
-                warning_dialog(_('No matching files'),
-                               _('No added files were found in the working tree.'))
+                warning_dialog(_i18n('No matching files'),
+                               _i18n('No added files were found in the working tree.'))
                 return
             self.wt.remove(file_list)
         
@@ -102,10 +103,10 @@
         self.selected = selected
         
         # Create widgets
-        self._label = gtk.Label(_("Which file(s) do you want to remove?"))
-        self._radio_selected = gtk.RadioButton(None, _("Selected only"), False)
-        self._radio_added = gtk.RadioButton(self._radio_selected, _("All files with status 'added'"), False)
-        self._button_remove = gtk.Button(_("_Remove"), use_underline=True)
+        self._label = gtk.Label(_i18n("Which file(s) do you want to remove?"))
+        self._radio_selected = gtk.RadioButton(None, _i18n("Selected only"), False)
+        self._radio_added = gtk.RadioButton(self._radio_selected, _i18n("All files with status 'added'"), False)
+        self._button_remove = gtk.Button(_i18n("_Remove"), use_underline=True)
         
         self._button_remove.connect('clicked', self._on_remove_clicked)
         
@@ -126,8 +127,8 @@
             filename = self.selected
             
             if filename is None:
-                error_dialog(_('No file was selected'),
-                             _('Please select a file from the list,\nor choose the other option.'))
+                error_dialog(_i18n('No file was selected'),
+                             _i18n('Please select a file from the list,\nor choose the other option.'))
                 return
             
             self.wt.remove(os.path.join(self.wtpath, filename))
@@ -136,8 +137,8 @@
             added = self.wt.changes_from(self.wt.basis_tree()).added
             file_list = sorted([f[0] for f in added], reverse=True)
             if len(file_list) == 0:
-                warning_dialog(_('No matching files'),
-                               _('No added files were found in the working tree.'))
+                warning_dialog(_i18n('No matching files'),
+                               _i18n('No added files were found in the working tree.'))
                 return
             self.wt.remove(file_list)
         

=== modified file 'olive/rename.py'
--- olive/rename.py	2007-07-19 14:08:51 +0000
+++ olive/rename.py	2008-05-05 18:16:46 +0000
@@ -31,6 +31,7 @@
 from errors import show_bzr_error
 from bzrlib.plugins.gtk.dialog import error_dialog
 from guifiles import GLADEFILENAME
+from bzrlib.plugins.gtk import _i18n
 
 
 class OliveRename:
@@ -67,13 +68,13 @@
         new_filename = self.entry.get_text()
             
         if old_filename is None:
-            error_dialog(_('No file was selected'),
-                         _('Please select a file from the list to proceed.'))
+            error_dialog(_i18n('No file was selected'),
+                         _i18n('Please select a file from the list to proceed.'))
             return
         
         if new_filename == "":
-            error_dialog(_('Filename not given'),
-                         _('Please specify a new name for the file.'))
+            error_dialog(_i18n('Filename not given'),
+                         _i18n('Please specify a new name for the file.'))
             return
         
         source = os.path.join(self.wtpath, old_filename)
@@ -84,8 +85,8 @@
         wt2, path2 = WorkingTree.open_containing(self.wt.abspath(source))
 
         if wt1.basedir != wt2.basedir:
-            error_dialog(_('Not the same branch'),
-                         _('The destination is not in the same branch.'))
+            error_dialog(_i18n('Not the same branch'),
+                         _i18n('The destination is not in the same branch.'))
             return
         wt1.rename_one(source, destination)
         self.close()

=== modified file 'po/olive-gtk.pot'
--- po/olive-gtk.pot	2007-08-13 10:08:10 +0000
+++ po/olive-gtk.pot	2008-05-05 18:16:46 +0000
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: PACKAGE VERSION\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2007-08-13 12:05+0200\n"
+"POT-Creation-Date: 2008-05-05 20:10+0200\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
@@ -16,76 +16,80 @@
 "Content-Type: text/plain; charset=CHARSET\n"
 "Content-Transfer-Encoding: 8bit\n"
 
-#: branch.py:52 olive.glade:151
+#: branch.py:52 olive.glade:151 olive.glade:167
 msgid "_Branch"
 msgstr ""
 
-#: branch.py:55 checkout.py:53
+#: branch.py:55 checkout.py:53 branch.py:60 checkout.py:54
 msgid "Please select a folder"
 msgstr ""
 
-#: branch.py:57 checkout.py:55
+#: branch.py:57 checkout.py:55 branch.py:55 checkout.py:56
 msgid "Branch location:"
 msgstr ""
 
-#: branch.py:58 checkout.py:56
+#: branch.py:58 checkout.py:56 branch.py:57 checkout.py:57
 msgid "Destination:"
 msgstr ""
 
-#: branch.py:59 checkout.py:57
+#: branch.py:59 checkout.py:57 branch.py:58 checkout.py:58
 msgid "Branck nick:"
 msgstr ""
 
-#: branch.py:60 checkout.py:58
+#: branch.py:60 checkout.py:58 branch.py:59 checkout.py:59
 msgid "Revision:"
 msgstr ""
 
-#: branch.py:162 checkout.py:163
+#: branch.py:162 checkout.py:163 branch.py:140 checkout.py:164
 msgid "Missing branch location"
 msgstr ""
 
-#: branch.py:163 checkout.py:164
+#: branch.py:163 checkout.py:164 branch.py:141 checkout.py:165
 msgid "You must specify a branch location."
 msgstr ""
 
-#: branch.py:205
+#: branch.py:205 branch.py:182
 msgid "Branching successful"
 msgstr ""
 
-#: branch.py:206
+#: branch.py:206 branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr ""
 
-#: branch.py:214 checkout.py:195
+#: branch.py:214 checkout.py:195 branch.py:191 checkout.py:196
 msgid "N/A"
 msgstr ""
 
-#: checkout.py:50
+#: checkout.py:50 checkout.py:51
 msgid "Check_out"
 msgstr ""
 
-#: checkout.py:62
+#: checkout.py:62 checkout.py:63
 msgid "_Lightweight checkout"
 msgstr ""
 
-#: commit.py:68
+#: commit.py:68 __init__.py:362
 msgid "Directory does not have a working tree"
 msgstr ""
 
-#: commit.py:69
+#: commit.py:69 __init__.py:363
 msgid "Operation aborted."
 msgstr ""
 
-#: commit.py:74 errors.py:26 add.py:76 add.py:86 info.py:556
+#: commit.py:74 errors.py:26 add.py:76 add.py:86 info.py:556 olive/add.py:76
+#: olive/add.py:86 olive/info.py:556 errors.py:28 olive/add.py:77
+#: olive/add.py:87 olive/info.py:557
 msgid "Directory is not a branch"
 msgstr ""
 
-#: commit.py:75 errors.py:27 add.py:77 add.py:87 info.py:557
+#: commit.py:75 errors.py:27 add.py:77 add.py:87 info.py:557 olive/add.py:77
+#: olive/add.py:87 olive/info.py:557 errors.py:29 olive/add.py:78
+#: olive/add.py:88 olive/info.py:558
 msgid "You can perform this action only in a branch."
 msgstr ""
 
-#: commit.py:88
+#: commit.py:88 commit.py:337 commit.py:338
 msgid "Comm_it"
 msgstr ""
 
@@ -101,27 +105,27 @@
 msgid "Pending merges"
 msgstr ""
 
-#: commit.py:147
+#: commit.py:147 commit.py:310 commit.py:311
 msgid "_Only commit locally"
 msgstr ""
 
-#: commit.py:215
+#: commit.py:215 commit.py:650 commit.py:652
 msgid "Commit with an empty message?"
 msgstr ""
 
-#: commit.py:216
+#: commit.py:216 commit.py:651 commit.py:653
 msgid "You can describe your commit intent in the message."
 msgstr ""
 
-#: commit.py:228
+#: commit.py:228 commit.py:670 commit.py:672
 msgid "Commit with unknowns?"
 msgstr ""
 
-#: commit.py:229
+#: commit.py:229 commit.py:671 commit.py:673
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 
-#: commit.py:240
+#: commit.py:240 commit.py:689 commit.py:691
 msgid "Commit with no changes?"
 msgstr ""
 
@@ -129,340 +133,360 @@
 msgid "There are no changes in the working tree."
 msgstr ""
 
-#: commit.py:323 menu.py:87
+#: commit.py:323 menu.py:87 commit.py:415 olive/menu.py:86 commit.py:416
+#: olive/menu.py:87
 msgid "Commit"
 msgstr ""
 
-#: commit.py:325 conflicts.py:108
+#: commit.py:325 conflicts.py:108 commit.py:419 conflicts.py:109 commit.py:420
+#: conflicts.py:110
 msgid "Path"
 msgstr ""
 
-#: commit.py:327 conflicts.py:110
+#: commit.py:327 conflicts.py:110 commit.py:421 conflicts.py:111 commit.py:422
+#: conflicts.py:112
 msgid "Type"
 msgstr ""
 
 #: commit.py:334 commit.py:336 commit.py:338 __init__.py:940 __init__.py:1227
+#: commit.py:167 olive/__init__.py:1053 olive/__init__.py:1358 commit.py:168
+#: olive/__init__.py:1054 olive/__init__.py:1359
 msgid "added"
 msgstr ""
 
 #: commit.py:344 commit.py:346 commit.py:348 __init__.py:938 __init__.py:1225
+#: commit.py:168 olive/__init__.py:1051 olive/__init__.py:1356 commit.py:169
+#: olive/__init__.py:1052 olive/__init__.py:1357
 msgid "removed"
 msgstr ""
 
-#: commit.py:353
+#: commit.py:353 commit.py:170 commit.py:171
 msgid "renamed and modified"
 msgstr ""
 
-#: commit.py:355 __init__.py:936 __init__.py:1223
+#: commit.py:355 __init__.py:936 __init__.py:1223 commit.py:169
+#: olive/__init__.py:1049 olive/__init__.py:1354 commit.py:170
+#: olive/__init__.py:1050 olive/__init__.py:1355
 msgid "renamed"
 msgstr ""
 
 #: commit.py:380 commit.py:382 commit.py:384 __init__.py:942 __init__.py:1229
+#: commit.py:171 olive/__init__.py:1055 olive/__init__.py:1360 commit.py:172
+#: olive/__init__.py:1056 olive/__init__.py:1361
 msgid "modified"
 msgstr ""
 
-#: commit.py:395
+#: commit.py:395 commit.py:480 commit.py:481
 msgid "Date"
 msgstr ""
 
-#: commit.py:397 revbrowser.py:68
+#: commit.py:397 revbrowser.py:68 commit.py:482 commit.py:483
 msgid "Committer"
 msgstr ""
 
-#: commit.py:399 revbrowser.py:66
+#: commit.py:399 revbrowser.py:66 commit.py:484 commit.py:485
 msgid "Summary"
 msgstr ""
 
-#: conflicts.py:48
+#: conflicts.py:48 conflicts.py:49
 msgid "External utility:"
 msgstr ""
 
-#: conflicts.py:99
+#: conflicts.py:99 conflicts.py:100
 msgid "Conflicts"
 msgstr ""
 
-#: conflicts.py:102
+#: conflicts.py:102 conflicts.py:103
 msgid "No conflicts in working tree."
 msgstr ""
 
-#: conflicts.py:115
+#: conflicts.py:115 conflicts.py:116 conflicts.py:117
 msgid "path conflict"
 msgstr ""
 
-#: conflicts.py:117
+#: conflicts.py:117 conflicts.py:118 conflicts.py:119
 msgid "contents conflict"
 msgstr ""
 
-#: conflicts.py:119
+#: conflicts.py:119 conflicts.py:120 conflicts.py:121
 msgid "text conflict"
 msgstr ""
 
-#: conflicts.py:121
+#: conflicts.py:121 conflicts.py:122 conflicts.py:123
 msgid "duplicate id"
 msgstr ""
 
-#: conflicts.py:123
+#: conflicts.py:123 conflicts.py:124 conflicts.py:125
 msgid "duplicate"
 msgstr ""
 
-#: conflicts.py:125
+#: conflicts.py:125 conflicts.py:126 conflicts.py:127
 msgid "parent loop"
 msgstr ""
 
-#: conflicts.py:127
+#: conflicts.py:127 conflicts.py:128 conflicts.py:129
 msgid "unversioned parent"
 msgstr ""
 
-#: conflicts.py:129
+#: conflicts.py:129 conflicts.py:130 conflicts.py:131
 msgid "missing parent"
 msgstr ""
 
-#: conflicts.py:131
+#: conflicts.py:131 conflicts.py:132 conflicts.py:133
 msgid "deleting parent"
 msgstr ""
 
-#: conflicts.py:133
+#: conflicts.py:133 conflicts.py:134 conflicts.py:135
 msgid "unknown type of conflict"
 msgstr ""
 
 #: conflicts.py:162 __init__.py:614 add.py:67 menu.py:178 menu.py:191
 #: menu.py:218 menu.py:254 move.py:79 remove.py:67 remove.py:129 rename.py:70
+#: conflicts.py:163 olive/__init__.py:687 olive/add.py:67 olive/menu.py:177
+#: olive/menu.py:190 olive/menu.py:217 olive/menu.py:253 olive/move.py:79
+#: olive/remove.py:67 olive/remove.py:129 olive/rename.py:70 conflicts.py:164
+#: olive/__init__.py:688 olive/add.py:68 olive/menu.py:178 olive/menu.py:191
+#: olive/menu.py:218 olive/menu.py:254 olive/move.py:80 olive/remove.py:68
+#: olive/remove.py:130 olive/rename.py:71
 msgid "No file was selected"
 msgstr ""
 
-#: conflicts.py:163 __init__.py:615 menu.py:192
+#: conflicts.py:163 __init__.py:615 menu.py:192 conflicts.py:164
+#: olive/__init__.py:688 olive/menu.py:191 conflicts.py:165
+#: olive/__init__.py:689 olive/menu.py:192
 msgid "Please select a file from the list."
 msgstr ""
 
-#: conflicts.py:173
+#: conflicts.py:173 conflicts.py:174 conflicts.py:175
 msgid "Call to external utility failed"
 msgstr ""
 
-#: conflicts.py:175
+#: conflicts.py:175 conflicts.py:176 conflicts.py:177
 msgid "Cannot resolve conflict"
 msgstr ""
 
-#: conflicts.py:176
+#: conflicts.py:176 conflicts.py:177 conflicts.py:178
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
 "using the command line."
 msgstr ""
 
-#: errors.py:29
+#: errors.py:29 errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: errors.py:30
+#: errors.py:30 errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: errors.py:32
+#: errors.py:32 errors.py:34
 msgid "No changes to commit"
 msgstr ""
 
-#: errors.py:33
+#: errors.py:33 errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: errors.py:35
+#: errors.py:35 errors.py:37
 msgid "Conflicts in tree"
 msgstr ""
 
-#: errors.py:36
+#: errors.py:36 errors.py:38
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: errors.py:38
+#: errors.py:38 errors.py:40
 msgid "Strict commit failed"
 msgstr ""
 
-#: errors.py:39
+#: errors.py:39 errors.py:41
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: errors.py:41
+#: errors.py:41 errors.py:43
 msgid "Bound branch is out of date"
 msgstr ""
 
-#: errors.py:42
+#: errors.py:42 errors.py:45
 #, python-format
 msgid "%s"
 msgstr ""
 
-#: errors.py:44
+#: errors.py:44 errors.py:47
 msgid "File not versioned"
 msgstr ""
 
-#: errors.py:45
+#: errors.py:45 errors.py:48
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: errors.py:47 push.py:105
+#: errors.py:47 push.py:105 errors.py:50 push.py:106
 msgid "Branches have been diverged"
 msgstr ""
 
-#: errors.py:48
+#: errors.py:48 errors.py:51
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: errors.py:50
+#: errors.py:50 errors.py:53
 msgid "No diff output"
 msgstr ""
 
-#: errors.py:51
+#: errors.py:51 errors.py:54
 msgid "The selected file hasn't changed."
 msgstr ""
 
-#: errors.py:53
+#: errors.py:53 errors.py:56
 msgid "No such revision"
 msgstr ""
 
-#: errors.py:54
+#: errors.py:54 errors.py:57
 msgid "The revision you specified doesn't exist."
 msgstr ""
 
-#: errors.py:56
+#: errors.py:56 errors.py:59
 msgid "Target already exists"
 msgstr ""
 
-#: errors.py:57
+#: errors.py:57 errors.py:60
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 
-#: errors.py:59
+#: errors.py:59 errors.py:62
 msgid "Directory is already a branch"
 msgstr ""
 
-#: errors.py:60
+#: errors.py:60 errors.py:63
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: errors.py:62
+#: errors.py:62 errors.py:65
 msgid "Branch without a working tree"
 msgstr ""
 
-#: errors.py:63
+#: errors.py:63 errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: errors.py:65
+#: errors.py:65 errors.py:68
 msgid "Unknown bzr error"
 msgstr ""
 
-#: errors.py:67
+#: errors.py:67 errors.py:70
 msgid "Permission denied"
 msgstr ""
 
-#: errors.py:67
+#: errors.py:67 errors.py:70
 msgid "permission denied."
 msgstr ""
 
-#: errors.py:69
+#: errors.py:69 errors.py:72
 msgid "Unknown error"
 msgstr ""
 
-#: initialize.py:47
+#: initialize.py:47 initialize.py:48
 msgid "_Initialize"
 msgstr ""
 
-#: initialize.py:48
+#: initialize.py:48 initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: initialize.py:49
+#: initialize.py:49 initialize.py:50
 msgid "Current directory"
 msgstr ""
 
-#: initialize.py:50
+#: initialize.py:50 initialize.py:51
 msgid "Create a new directory with the name:"
 msgstr ""
 
-#: initialize.py:85
+#: initialize.py:85 initialize.py:86
 msgid "Directory name not specified"
 msgstr ""
 
-#: initialize.py:86
+#: initialize.py:86 initialize.py:87
 msgid "You should specify a new directory name."
 msgstr ""
 
-#: merge.py:66
+#: merge.py:66 merge.py:68 merge.py:69
 msgid "Branch not given"
 msgstr ""
 
-#: merge.py:67
+#: merge.py:67 merge.py:69 merge.py:70
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: merge.py:75
+#: merge.py:75 merge.py:77 merge.py:78
 msgid "Bazaar command error"
 msgstr ""
 
-#: merge.py:81
+#: merge.py:81 diff.py:513 merge.py:83 diff.py:514 merge.py:84
 msgid "Merge successful"
 msgstr ""
 
-#: merge.py:82
+#: merge.py:82 diff.py:514 merge.py:84 diff.py:515 merge.py:85
 msgid "All changes applied successfully."
 msgstr ""
 
-#: merge.py:85
+#: merge.py:85 diff.py:517 merge.py:87 diff.py:518 merge.py:88
 msgid "Conflicts encountered"
 msgstr ""
 
-#: merge.py:86
+#: merge.py:86 diff.py:518 merge.py:88 diff.py:519 merge.py:89
 msgid "Please resolve the conflicts manually before committing."
 msgstr ""
 
-#: push.py:52 bookmark.py:45
+#: push.py:52 bookmark.py:45 olive/bookmark.py:45 push.py:53
+#: olive/bookmark.py:46
 msgid "Location:"
 msgstr ""
 
-#: push.py:54
+#: push.py:54 push.py:55
 msgid "_Push"
 msgstr ""
 
-#: push.py:97
+#: push.py:97 push.py:98
 msgid "Set default push location"
 msgstr ""
 
-#: push.py:98
+#: push.py:98 push.py:99
 #, python-format
 msgid ""
 "There is no default push location set.\n"
 "Set %r as default now?"
 msgstr ""
 
-#: push.py:106
+#: push.py:106 push.py:107
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
-#: push.py:112
+#: push.py:112 push.py:111
 msgid "Push successful"
 msgstr ""
 
-#: push.py:113
+#: push.py:113 push.py:112
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: push.py:146
+#: push.py:146 push.py:145
 msgid "Non existing parent directory"
 msgstr ""
 
-#: push.py:147
+#: push.py:147 push.py:146
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -473,7 +497,7 @@
 msgid "Please wait, revisions are being loaded..."
 msgstr ""
 
-#: revbrowser.py:48
+#: revbrowser.py:48 revbrowser.py:44 revbrowser.py:45
 msgid "_Select"
 msgstr ""
 
@@ -485,100 +509,101 @@
 msgid "Time"
 msgstr ""
 
-#: status.py:78
+#: status.py:78 status.py:82 status.py:84
 msgid "Added"
 msgstr ""
 
-#: status.py:84
+#: status.py:84 status.py:88 status.py:90
 msgid "Removed"
 msgstr ""
 
-#: status.py:90
+#: status.py:90 status.py:94 status.py:96
 msgid "Renamed"
 msgstr ""
 
-#: status.py:97
+#: status.py:97 status.py:101 status.py:103
 msgid "Modified"
 msgstr ""
 
-#: status.py:105
+#: status.py:105 status.py:109 status.py:111
 msgid "Unknown"
 msgstr ""
 
-#: status.py:110
+#: status.py:110 status.py:114 status.py:116
 msgid "No changes."
 msgstr ""
 
-#: tags.py:67
+#: tags.py:67 tags.py:65 tags.py:66
 msgid "Tags"
 msgstr ""
 
-#: tags.py:111
+#: tags.py:111 tags.py:109 tags.py:110
 msgid "Tag Name"
 msgstr ""
 
-#: tags.py:116
+#: tags.py:116 tags.py:114 tags.py:115
 msgid "Revision ID"
 msgstr ""
 
-#: tags.py:151
+#: tags.py:151 tags.py:149 tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: tags.py:157
+#: tags.py:157 tags.py:155 tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr ""
 
-#: tags.py:232
+#: tags.py:232 tags.py:230 tags.py:231
 msgid "_Remove tag"
 msgstr ""
 
-#: tags.py:242
+#: tags.py:242 tags.py:240 tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr ""
 
-#: tags.py:244
+#: tags.py:244 tags.py:242 tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr ""
 
-#: tags.py:289
+#: tags.py:289 tags.py:287 tags.py:288
 msgid "_Add tag"
 msgstr ""
 
-#: tags.py:291
+#: tags.py:291 tags.py:289 tags.py:290
 msgid "Tag Name:"
 msgstr ""
 
-#: tags.py:292
+#: tags.py:292 tags.py:290 tags.py:291
 msgid "Revision ID:"
 msgstr ""
 
-#: tags.py:323
+#: tags.py:323 tags.py:321 tags.py:322
 msgid "No tag name specified"
 msgstr ""
 
-#: tags.py:324
+#: tags.py:324 tags.py:322 tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
 
-#: __init__.py:512
+#: __init__.py:512 olive/__init__.py:539 olive/__init__.py:540
 msgid "There are local changes in the branch"
 msgstr ""
 
-#: __init__.py:513
+#: __init__.py:513 olive/__init__.py:540 olive/__init__.py:541
 msgid "Please commit or revert the changes before merging."
 msgstr ""
 
-#: __init__.py:525 __init__.py:550
+#: __init__.py:525 __init__.py:550 olive/__init__.py:555 olive/__init__.py:612
+#: olive/__init__.py:556 olive/__init__.py:613
 msgid "Parent location is unknown"
 msgstr ""
 
-#: __init__.py:526
+#: __init__.py:526 olive/__init__.py:556 olive/__init__.py:557
 msgid "Cannot determine missing revisions if no parent location is known."
 msgstr ""
 
-#: __init__.py:537
+#: __init__.py:537 olive/__init__.py:599 olive/__init__.py:600
 msgid "There are missing revisions"
 msgstr ""
 
@@ -587,318 +612,346 @@
 msgid "%d revision(s) missing."
 msgstr ""
 
-#: __init__.py:540
+#: __init__.py:540 olive/__init__.py:602 olive/__init__.py:603
 msgid "Local branch up to date"
 msgstr ""
 
-#: __init__.py:541
+#: __init__.py:541 olive/__init__.py:603 olive/__init__.py:604
 msgid "There are no missing revisions."
 msgstr ""
 
-#: __init__.py:551
+#: __init__.py:551 olive/__init__.py:613 olive/__init__.py:614
 msgid "Pulling is not possible until there is a parent location."
 msgstr ""
 
-#: __init__.py:561
+#: __init__.py:561 olive/__init__.py:623 olive/__init__.py:624
 msgid "Pull successful"
 msgstr ""
 
-#: __init__.py:561
+#: __init__.py:561 olive/__init__.py:623 olive/__init__.py:624
 #, python-format
 msgid "%d revision(s) pulled."
 msgstr ""
 
-#: __init__.py:575 menu.py:275
+#: __init__.py:575 menu.py:275 olive/__init__.py:648 olive/menu.py:274
+#: olive/__init__.py:649 olive/menu.py:275
 msgid "Conflicts detected"
 msgstr ""
 
-#: __init__.py:576 menu.py:276
+#: __init__.py:576 menu.py:276 olive/__init__.py:649 olive/menu.py:275
+#: olive/__init__.py:650 olive/menu.py:276
 msgid "Please have a look at the working tree before continuing."
 msgstr ""
 
-#: __init__.py:578 menu.py:278
+#: __init__.py:578 menu.py:278 olive/__init__.py:651 olive/menu.py:277
+#: olive/__init__.py:652 olive/menu.py:278
 msgid "Revert successful"
 msgstr ""
 
-#: __init__.py:579 menu.py:279
+#: __init__.py:579 menu.py:279 olive/__init__.py:652 olive/menu.py:278
+#: olive/__init__.py:653 olive/menu.py:279
 msgid "All files reverted to last revision."
 msgstr ""
 
-#: __init__.py:835 __init__.py:1117
+#: __init__.py:835 __init__.py:1117 olive/__init__.py:942
+#: olive/__init__.py:1240 olive/__init__.py:943 olive/__init__.py:1241
 msgid "Bookmarks"
 msgstr ""
 
-#: __init__.py:842 menu.py:99
+#: __init__.py:842 menu.py:99 olive/__init__.py:949 olive/menu.py:98
+#: olive/__init__.py:950 olive/menu.py:99
 msgid "Bookmark"
 msgstr ""
 
-#: __init__.py:944 __init__.py:1231
+#: __init__.py:944 __init__.py:1231 olive/__init__.py:1057
+#: olive/__init__.py:1362 olive/__init__.py:1058 olive/__init__.py:1363
 msgid "unchanged"
 msgstr ""
 
-#: __init__.py:946 __init__.py:1233
+#: __init__.py:946 __init__.py:1233 olive/__init__.py:1059
+#: olive/__init__.py:1364 olive/__init__.py:1060 olive/__init__.py:1365
 msgid "ignored"
 msgstr ""
 
-#: __init__.py:948 __init__.py:1235
+#: __init__.py:948 __init__.py:1235 olive/__init__.py:1061
+#: olive/__init__.py:1368 olive/__init__.py:1062 olive/__init__.py:1369
 msgid "unknown"
 msgstr ""
 
-#: __init__.py:964
+#: __init__.py:964 olive/__init__.py:1083 olive/__init__.py:1084
 msgid "Filename"
 msgstr ""
 
-#: __init__.py:965
+#: __init__.py:965 olive/__init__.py:1084 olive/__init__.py:1085
 msgid "Status"
 msgstr ""
 
-#: __init__.py:966
+#: __init__.py:966 olive/__init__.py:1085 olive/__init__.py:1086
 msgid "Size"
 msgstr ""
 
-#: __init__.py:967
+#: __init__.py:967 olive/__init__.py:1086 olive/__init__.py:1087
 msgid "Last modified"
 msgstr ""
 
 #: add.py:68 menu.py:179 menu.py:219 menu.py:255 remove.py:68 remove.py:130
+#: olive/add.py:68 olive/menu.py:178 olive/menu.py:218 olive/menu.py:254
+#: olive/remove.py:68 olive/remove.py:130 olive/add.py:69 olive/menu.py:179
+#: olive/menu.py:219 olive/menu.py:255 olive/remove.py:69 olive/remove.py:131
 msgid ""
 "Please select a file from the list,\n"
 "or choose the other option."
 msgstr ""
 
-#: bookmark.py:46
+#: bookmark.py:46 olive/bookmark.py:46 olive/bookmark.py:47
 msgid "Title:"
 msgstr ""
 
-#: bookmark.py:81
+#: bookmark.py:81 olive/bookmark.py:81 olive/bookmark.py:82
 msgid "No title given"
 msgstr ""
 
-#: bookmark.py:82
+#: bookmark.py:82 olive/bookmark.py:82 olive/bookmark.py:83
 msgid "Please specify a title to continue."
 msgstr ""
 
-#: guifiles.py:45
+#: guifiles.py:45 olive/guifiles.py:47 olive/guifiles.py:48
 msgid "Glade file cannot be found."
 msgstr ""
 
-#: guifiles.py:55
+#: guifiles.py:55 olive/guifiles.py:57 olive/guifiles.py:58
 msgid "UI description file cannot be found."
 msgstr ""
 
-#: menu.py:63
+#: menu.py:63 olive/menu.py:62 olive/menu.py:63
 msgid "Add"
 msgstr ""
 
-#: menu.py:64
+#: menu.py:64 olive/menu.py:63 olive/menu.py:64
 msgid "Add the selected file"
 msgstr ""
 
-#: menu.py:67 menu.py:107
+#: menu.py:67 menu.py:107 olive/menu.py:66 olive/menu.py:106 olive/menu.py:67
+#: olive/menu.py:107
 msgid "Remove"
 msgstr ""
 
-#: menu.py:68
+#: menu.py:68 olive/menu.py:67 olive/menu.py:68
 msgid "Remove the selected file"
 msgstr ""
 
-#: menu.py:71
+#: menu.py:71 olive/menu.py:70 olive/menu.py:71
 msgid "Remove and delete"
 msgstr ""
 
-#: menu.py:72
+#: menu.py:72 olive/menu.py:71 olive/menu.py:72
 msgid "Remove the selected file/dir and delete from disk"
 msgstr ""
 
-#: menu.py:75
+#: menu.py:75 olive/menu.py:74 olive/menu.py:75
 msgid "Rename"
 msgstr ""
 
-#: menu.py:76
+#: menu.py:76 olive/menu.py:75 olive/menu.py:76
 msgid "Rename the selected file"
 msgstr ""
 
-#: menu.py:79
+#: menu.py:79 olive/menu.py:78 olive/menu.py:79
 msgid "Open"
 msgstr ""
 
-#: menu.py:80
+#: menu.py:80 olive/menu.py:79 olive/menu.py:80
 msgid "Open the selected file"
 msgstr ""
 
-#: menu.py:83
+#: menu.py:83 olive/menu.py:82 olive/menu.py:83
 msgid "Revert"
 msgstr ""
 
-#: menu.py:84
+#: menu.py:84 olive/menu.py:83 olive/menu.py:84
 msgid "Revert the changes"
 msgstr ""
 
-#: menu.py:88
+#: menu.py:88 olive/menu.py:87 olive/menu.py:88
 msgid "Commit the changes"
 msgstr ""
 
-#: menu.py:91
+#: menu.py:91 olive/menu.py:90 olive/menu.py:91
 msgid "Annotate"
 msgstr ""
 
-#: menu.py:92
+#: menu.py:92 olive/menu.py:91 olive/menu.py:92
 msgid "Annotate the selected file"
 msgstr ""
 
-#: menu.py:95
+#: menu.py:95 olive/menu.py:94 olive/menu.py:95
 msgid "Diff"
 msgstr ""
 
-#: menu.py:96
+#: menu.py:96 olive/menu.py:95 olive/menu.py:96
 msgid "Show the diff of the file"
 msgstr ""
 
-#: menu.py:100
+#: menu.py:100 olive/menu.py:99 olive/menu.py:100
 msgid "Bookmark current location"
 msgstr ""
 
-#: menu.py:103
+#: menu.py:103 olive/menu.py:102 olive/menu.py:103
 msgid "Edit"
 msgstr ""
 
-#: menu.py:104
+#: menu.py:104 olive/menu.py:103 olive/menu.py:104
 msgid "Edit the selected bookmark"
 msgstr ""
 
-#: menu.py:108
+#: menu.py:108 olive/menu.py:107 olive/menu.py:108
 msgid "Remove the selected bookmark"
 msgstr ""
 
-#: menu.py:111
+#: menu.py:111 olive/menu.py:110 olive/menu.py:111
 msgid "Open Folder"
 msgstr ""
 
-#: menu.py:112
+#: menu.py:112 olive/menu.py:111 olive/menu.py:112
 msgid "Open bookmark folder in Nautilus"
 msgstr ""
 
-#: menu.py:115
+#: menu.py:115 olive/menu.py:114 olive/menu.py:115
 msgid "Selected..."
 msgstr ""
 
-#: menu.py:116
+#: menu.py:116 olive/menu.py:115 olive/menu.py:116
 msgid "Show the differences of the selected file"
 msgstr ""
 
-#: menu.py:119
+#: menu.py:119 olive/menu.py:118 olive/menu.py:119
 msgid "All..."
 msgstr ""
 
-#: menu.py:120
+#: menu.py:120 olive/menu.py:119 olive/menu.py:120
 msgid "Show the differences of all files"
 msgstr ""
 
-#: menu.py:123
+#: menu.py:123 olive/menu.py:122 olive/menu.py:123
 msgid "View contents"
 msgstr ""
 
-#: menu.py:124
+#: menu.py:124 olive/menu.py:123 olive/menu.py:124
 msgid "View the contents of the file in a builtin viewer"
 msgstr ""
 
-#: menu.py:127
+#: menu.py:127 olive/menu.py:126 olive/menu.py:127
 msgid "Show differences"
 msgstr ""
 
-#: menu.py:128
+#: menu.py:128 olive/menu.py:127 olive/menu.py:128
 msgid "Show the differences between two revisions of the file"
 msgstr ""
 
-#: menu.py:131
+#: menu.py:131 olive/menu.py:130 olive/menu.py:131
 msgid "Revert to this revision"
 msgstr ""
 
-#: menu.py:132
+#: menu.py:132 olive/menu.py:131 olive/menu.py:132
 msgid "Revert the selected file to the selected revision"
 msgstr ""
 
-#: menu.py:228
+#: menu.py:228 olive/menu.py:227 olive/menu.py:228
 msgid "Delete directory with all directories below ?"
 msgstr ""
 
-#: menu.py:315
+#: menu.py:315 olive/__init__.py:707 olive/menu.py:318 olive/__init__.py:708
+#: olive/menu.py:319
 msgid "Bookmark successfully added"
 msgstr ""
 
-#: menu.py:316
+#: menu.py:316 olive/__init__.py:708 olive/menu.py:319 olive/__init__.py:709
+#: olive/menu.py:320
 msgid ""
 "The current directory was bookmarked. You can reach\n"
 "it by selecting it from the left panel."
 msgstr ""
 
-#: menu.py:319
+#: menu.py:319 olive/__init__.py:711 olive/menu.py:322 olive/__init__.py:712
+#: olive/menu.py:323
 msgid "Location already bookmarked"
 msgstr ""
 
-#: menu.py:320
+#: menu.py:320 olive/__init__.py:712 olive/menu.py:323 olive/__init__.py:713
+#: olive/menu.py:324
 msgid ""
 "The current directory is already bookmarked.\n"
 "See the left panel for reference."
 msgstr ""
 
-#: mkdir.py:67
+#: mkdir.py:67 olive/mkdir.py:67 olive/mkdir.py:68
 msgid "No directory name given"
 msgstr ""
 
-#: mkdir.py:68
+#: mkdir.py:68 olive/mkdir.py:68 olive/mkdir.py:69
 msgid "Please specify a desired name for the new directory."
 msgstr ""
 
-#: mkdir.py:79 mkdir.py:89
+#: mkdir.py:79 mkdir.py:89 olive/mkdir.py:79 olive/mkdir.py:89
+#: olive/mkdir.py:80 olive/mkdir.py:90
 msgid "Directory already exists"
 msgstr ""
 
-#: mkdir.py:80 mkdir.py:90
+#: mkdir.py:80 mkdir.py:90 olive/mkdir.py:80 olive/mkdir.py:90
+#: olive/mkdir.py:81 olive/mkdir.py:91
 msgid "Please specify another name to continue."
 msgstr ""
 
-#: move.py:80 rename.py:71
+#: move.py:80 rename.py:71 olive/move.py:80 olive/rename.py:71
+#: olive/move.py:81 olive/rename.py:72
 msgid "Please select a file from the list to proceed."
 msgstr ""
 
-#: move.py:89 rename.py:87
+#: move.py:89 rename.py:87 olive/move.py:89 olive/rename.py:87
+#: olive/move.py:90 olive/rename.py:88
 msgid "Not the same branch"
 msgstr ""
 
-#: move.py:90 rename.py:88
+#: move.py:90 rename.py:88 olive/move.py:90 olive/rename.py:88
+#: olive/move.py:91 olive/rename.py:89
 msgid "The destination is not in the same branch."
 msgstr ""
 
-#: remove.py:79 remove.py:139
+#: remove.py:79 remove.py:139 olive/remove.py:79 olive/remove.py:139
+#: olive/remove.py:80 olive/remove.py:140
 msgid "No matching files"
 msgstr ""
 
-#: remove.py:80 remove.py:140
+#: remove.py:80 remove.py:140 olive/remove.py:80 olive/remove.py:140
+#: olive/remove.py:81 olive/remove.py:141
 msgid "No added files were found in the working tree."
 msgstr ""
 
-#: remove.py:105 olive.glade:825
+#: remove.py:105 olive.glade:825 olive.glade:878 olive/remove.py:105
+#: olive/remove.py:106
 msgid "Which file(s) do you want to remove?"
 msgstr ""
 
-#: remove.py:106 olive.glade:717 olive.glade:837
+#: remove.py:106 olive.glade:717 olive.glade:837 olive.glade:766
+#: olive.glade:890 olive/remove.py:106 olive/remove.py:107
 msgid "Selected only"
 msgstr ""
 
-#: remove.py:107 olive.glade:851
+#: remove.py:107 olive.glade:851 olive.glade:905 olive/remove.py:107
+#: olive/remove.py:108
 msgid "All files with status 'added'"
 msgstr ""
 
-#: remove.py:108 olive.glade:905
+#: remove.py:108 olive.glade:905 olive.glade:962 olive/remove.py:108
+#: olive/remove.py:109
 msgid "_Remove"
 msgstr ""
 
-#: rename.py:75
+#: rename.py:75 olive/rename.py:75 olive/rename.py:76
 msgid "Filename not given"
 msgstr ""
 
-#: rename.py:76
+#: rename.py:76 olive/rename.py:76 olive/rename.py:77
 msgid "Please specify a new name for the file."
 msgstr ""
 
@@ -918,183 +971,183 @@
 msgid "Remove file(s)..."
 msgstr ""
 
-#: olive.glade:63
+#: olive.glade:63 olive.glade:71
 msgid "Make _directory..."
 msgstr ""
 
-#: olive.glade:76
+#: olive.glade:76 olive.glade:84
 msgid "_Rename..."
 msgstr ""
 
-#: olive.glade:84
+#: olive.glade:84 olive.glade:92
 msgid "_Move..."
 msgstr ""
 
-#: olive.glade:92
+#: olive.glade:92 olive.glade:100
 msgid "_Annotate..."
 msgstr ""
 
-#: olive.glade:118
+#: olive.glade:118 olive.glade:126
 msgid "_View"
 msgstr ""
 
-#: olive.glade:126
+#: olive.glade:126 olive.glade:134
 msgid "Show _hidden files"
 msgstr ""
 
-#: olive.glade:139
+#: olive.glade:139 olive.glade:155
 msgid "_Refresh"
 msgstr ""
 
-#: olive.glade:158
+#: olive.glade:158 olive.glade:174
 msgid "_Initialize..."
 msgstr ""
 
-#: olive.glade:166
+#: olive.glade:166 olive.glade:182
 msgid "_Get..."
 msgstr ""
 
-#: olive.glade:174
+#: olive.glade:174 olive.glade:190
 msgid "C_heckout..."
 msgstr ""
 
-#: olive.glade:187
+#: olive.glade:187 olive.glade:203
 msgid "Pu_ll"
 msgstr ""
 
-#: olive.glade:201
+#: olive.glade:201 olive.glade:217
 msgid "Pu_sh..."
 msgstr ""
 
-#: olive.glade:220
+#: olive.glade:220 olive.glade:245
 msgid "_Revert all changes"
 msgstr ""
 
-#: olive.glade:228
+#: olive.glade:228 olive.glade:253
 msgid "_Merge..."
 msgstr ""
 
-#: olive.glade:236
+#: olive.glade:236 olive.glade:261
 msgid "_Commit..."
 msgstr ""
 
-#: olive.glade:255
+#: olive.glade:255 olive.glade:280
 msgid "Ta_gs..."
 msgstr ""
 
-#: olive.glade:263
+#: olive.glade:263 olive.glade:288
 msgid "S_tatus..."
 msgstr ""
 
-#: olive.glade:271
+#: olive.glade:271 olive.glade:296
 msgid "Missing _revisions"
 msgstr ""
 
-#: olive.glade:279
+#: olive.glade:279 olive.glade:304
 msgid "Con_flicts..."
 msgstr ""
 
-#: olive.glade:291
+#: olive.glade:291 olive.glade:316
 msgid "_Statistics"
 msgstr ""
 
-#: olive.glade:298
+#: olive.glade:298 olive.glade:323
 msgid "_Differences..."
 msgstr ""
 
-#: olive.glade:312
+#: olive.glade:312 olive.glade:337
 msgid "_Log..."
 msgstr ""
 
-#: olive.glade:326
+#: olive.glade:326 olive.glade:351
 msgid "_Information..."
 msgstr ""
 
-#: olive.glade:338
+#: olive.glade:338 olive.glade:363
 msgid "_Help"
 msgstr ""
 
-#: olive.glade:548
+#: olive.glade:548 olive.glade:590
 msgid "gtk-jump-to"
 msgstr ""
 
-#: olive.glade:575
+#: olive.glade:575 olive.glade:618
 msgid "H_istory Mode"
 msgstr ""
 
-#: olive.glade:673
+#: olive.glade:673 olive.glade:722
 msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
 msgstr ""
 
-#: olive.glade:675
+#: olive.glade:675 olive.glade:724
 msgid "https://launchpad.net/products/olive"
 msgstr ""
 
-#: olive.glade:677
+#: olive.glade:677 olive.glade:726
 msgid "translator-credits"
 msgstr ""
 
-#: olive.glade:694
+#: olive.glade:694 olive.glade:743
 msgid "Olive - Add file(s)"
 msgstr ""
 
-#: olive.glade:705
+#: olive.glade:705 olive.glade:754
 msgid "Which file(s) do you want to add?"
 msgstr ""
 
-#: olive.glade:731
+#: olive.glade:731 olive.glade:781
 msgid "All unknowns recursively"
 msgstr ""
 
-#: olive.glade:785
+#: olive.glade:785 olive.glade:838
 msgid "_Add"
 msgstr ""
 
-#: olive.glade:814
+#: olive.glade:814 olive.glade:867
 msgid "Olive - Remove file(s)"
 msgstr ""
 
-#: olive.glade:934
+#: olive.glade:934 olive.glade:991
 msgid "Olive - Make directory"
 msgstr ""
 
-#: olive.glade:957
+#: olive.glade:957 olive.glade:1014
 msgid "_Versioned directory"
 msgstr ""
 
-#: olive.glade:1011
+#: olive.glade:1011 olive.glade:1071
 msgid "_Make directory"
 msgstr ""
 
-#: olive.glade:1041
+#: olive.glade:1041 olive.glade:1101
 msgid "Olive - Move"
 msgstr ""
 
-#: olive.glade:1055
+#: olive.glade:1055 olive.glade:1115
 msgid "Move to"
 msgstr ""
 
-#: olive.glade:1066
+#: olive.glade:1066 olive.glade:1126
 msgid "Select a directory"
 msgstr ""
 
-#: olive.glade:1120
+#: olive.glade:1120 olive.glade:1182
 msgid "_Move"
 msgstr ""
 
-#: olive.glade:1148
+#: olive.glade:1148 olive.glade:1210
 msgid "Olive - Rename"
 msgstr ""
 
-#: olive.glade:1162
+#: olive.glade:1162 olive.glade:1224
 msgid "Rename to"
 msgstr ""
 
-#: olive.glade:1227
+#: olive.glade:1227 olive.glade:1291
 msgid "_Rename"
 msgstr ""
 
-#: olive.glade:1255
+#: olive.glade:1255 olive.glade:1319
 msgid "Olive - Information"
 msgstr ""
 
@@ -1106,182 +1159,305 @@
 #: olive.glade:1903 olive.glade:1916 olive.glade:1929 olive.glade:1942
 #: olive.glade:1955 olive.glade:1968 olive.glade:2109 olive.glade:2120
 #: olive.glade:2133 olive.glade:2146 olive.glade:2159 olive.glade:2264
-#: olive.glade:2275
+#: olive.glade:2275 olive.glade:1343 olive.glade:1356 olive.glade:1369
+#: olive.glade:1382 olive.glade:1395 olive.glade:1408 olive.glade:1421
+#: olive.glade:1548 olive.glade:1559 olive.glade:1628 olive.glade:1639
+#: olive.glade:1652 olive.glade:1665 olive.glade:1758 olive.glade:1769
+#: olive.glade:1782 olive.glade:1863 olive.glade:1874 olive.glade:1943
+#: olive.glade:1954 olive.glade:1967 olive.glade:1980 olive.glade:1993
+#: olive.glade:2006 olive.glade:2019 olive.glade:2032 olive.glade:2173
+#: olive.glade:2184 olive.glade:2197 olive.glade:2210 olive.glade:2223
+#: olive.glade:2328 olive.glade:2339
 msgid "(none)"
 msgstr ""
 
-#: olive.glade:1368
+#: olive.glade:1368 olive.glade:1432
 msgid "Checkout root: "
 msgstr ""
 
-#: olive.glade:1380
+#: olive.glade:1380 olive.glade:1444
 msgid "Branch root: "
 msgstr ""
 
-#: olive.glade:1392
+#: olive.glade:1392 olive.glade:1456
 msgid "Repository checkout: "
 msgstr ""
 
-#: olive.glade:1404
+#: olive.glade:1404 olive.glade:1468
 msgid "Checkout of branch: "
 msgstr ""
 
-#: olive.glade:1416
+#: olive.glade:1416 olive.glade:1480
 msgid "Repository branch: "
 msgstr ""
 
-#: olive.glade:1428
+#: olive.glade:1428 olive.glade:1492
 msgid "Shared repository: "
 msgstr ""
 
-#: olive.glade:1440
+#: olive.glade:1440 olive.glade:1504
 msgid "Light checkout root: "
 msgstr ""
 
-#: olive.glade:1454
+#: olive.glade:1454 olive.glade:1518
 msgid "<b>Location:</b>"
 msgstr ""
 
-#: olive.glade:1508
+#: olive.glade:1508 olive.glade:1572
 msgid "Publish to branch: "
 msgstr ""
 
-#: olive.glade:1520
+#: olive.glade:1520 olive.glade:1584
 msgid "Parent branch: "
 msgstr ""
 
-#: olive.glade:1534
+#: olive.glade:1534 olive.glade:1598
 msgid "<b>Related branches:</b>"
 msgstr ""
 
-#: olive.glade:1614
+#: olive.glade:1614 olive.glade:1678
 msgid "Repository format: "
 msgstr ""
 
-#: olive.glade:1626
+#: olive.glade:1626 olive.glade:1690
 msgid "Branch format: "
 msgstr ""
 
-#: olive.glade:1638
+#: olive.glade:1638 olive.glade:1702
 msgid "Working tree format: "
 msgstr ""
 
-#: olive.glade:1650
+#: olive.glade:1650 olive.glade:1714
 msgid "Control format: "
 msgstr ""
 
-#: olive.glade:1664
+#: olive.glade:1664 olive.glade:1728
 msgid "<b>Format:</b>"
 msgstr ""
 
-#: olive.glade:1731
+#: olive.glade:1731 olive.glade:1795
 msgid "Repository lock status: "
 msgstr ""
 
-#: olive.glade:1743
+#: olive.glade:1743 olive.glade:1807
 msgid "Branch lock status: "
 msgstr ""
 
-#: olive.glade:1755
+#: olive.glade:1755 olive.glade:1819
 msgid "Working tree lock status: "
 msgstr ""
 
-#: olive.glade:1769
+#: olive.glade:1769 olive.glade:1833
 msgid "<b>Lock status:</b>"
 msgstr ""
 
-#: olive.glade:1823
+#: olive.glade:1823 olive.glade:1887
 msgid "Missing revisions in branch: "
 msgstr ""
 
-#: olive.glade:1835
+#: olive.glade:1835 olive.glade:1899
 msgid "Missing revisions in working tree: "
 msgstr ""
 
-#: olive.glade:1849
+#: olive.glade:1849 olive.glade:1913
 msgid "<b>Missing revisions:</b>"
 msgstr ""
 
-#: olive.glade:1981
+#: olive.glade:1981 olive.glade:2045
 msgid "Versioned subdirectories: "
 msgstr ""
 
-#: olive.glade:1993
+#: olive.glade:1993 olive.glade:2057
 msgid "Ignored files: "
 msgstr ""
 
-#: olive.glade:2005
+#: olive.glade:2005 olive.glade:2069
 msgid "Unknown files: "
 msgstr ""
 
-#: olive.glade:2017
+#: olive.glade:2017 olive.glade:2081
 msgid "Renamed files: "
 msgstr ""
 
-#: olive.glade:2029
+#: olive.glade:2029 olive.glade:2093
 msgid "Removed files: "
 msgstr ""
 
-#: olive.glade:2041
+#: olive.glade:2041 olive.glade:2105
 msgid "Added files: "
 msgstr ""
 
-#: olive.glade:2053
+#: olive.glade:2053 olive.glade:2117
 msgid "Modified files: "
 msgstr ""
 
-#: olive.glade:2065
+#: olive.glade:2065 olive.glade:2129
 msgid "Unchanged files: "
 msgstr ""
 
-#: olive.glade:2079
+#: olive.glade:2079 olive.glade:2143
 msgid "<b>In the working tree:</b>"
 msgstr ""
 
-#: olive.glade:2172
+#: olive.glade:2172 olive.glade:2236
 msgid "Time of last revision: "
 msgstr ""
 
-#: olive.glade:2184
+#: olive.glade:2184 olive.glade:2248
 msgid "Time of first revision: "
 msgstr ""
 
-#: olive.glade:2196
+#: olive.glade:2196 olive.glade:2260
 msgid "Age of branch in days: "
 msgstr ""
 
-#: olive.glade:2208
+#: olive.glade:2208 olive.glade:2272
 msgid "Number of commiters: "
 msgstr ""
 
-#: olive.glade:2220
+#: olive.glade:2220 olive.glade:2284
 msgid "Revisions in branch: "
 msgstr ""
 
-#: olive.glade:2234
+#: olive.glade:2234 olive.glade:2298
 msgid "<b>Branch history:</b>"
 msgstr ""
 
-#: olive.glade:2288
+#: olive.glade:2288 olive.glade:2352
 msgid "Size of repository: "
 msgstr ""
 
-#: olive.glade:2300
+#: olive.glade:2300 olive.glade:2364
 msgid "Revisions in repository: "
 msgstr ""
 
-#: olive.glade:2314
+#: olive.glade:2314 olive.glade:2378
 msgid "<b>Revision store:</b>"
 msgstr ""
 
-#: olive.glade:2356
+#: olive.glade:2356 olive.glade:2421
 msgid "Merge - Olive"
 msgstr ""
 
-#: olive.glade:2370
+#: olive.glade:2370 olive.glade:2435
 msgid "Merge from:"
 msgstr ""
 
-#: olive.glade:2454
+#: olive.glade:2454 olive.glade:2522
 msgid "_Merge"
 msgstr ""
+
+#: olive.glade:63
+msgid "_Bookmark current directory"
+msgstr ""
+
+#: olive.glade:142
+msgid "Show _ignored files"
+msgstr ""
+
+#: olive.glade:232 olive.glade:486
+msgid "Update"
+msgstr ""
+
+#: commit.py:172 commit.py:173
+msgid "kind changed"
+msgstr ""
+
+#: commit.py:260 commit.py:261
+msgid "<b>Commit Message</b>"
+msgstr ""
+
+#: commit.py:363 commit.py:364
+msgid "Files"
+msgstr ""
+
+#: commit.py:368 commit.py:369
+msgid "Commit all changes"
+msgstr ""
+
+#: commit.py:374 commit.py:375
+msgid "Only commit selected changes"
+msgstr ""
+
+#: commit.py:380 commit.py:381
+msgid "Commit all changes*"
+msgstr ""
+
+#: commit.py:413 commit.py:414
+msgid "Commit*"
+msgstr ""
+
+#: commit.py:454 commit.py:455
+msgid "<i>* Cannot select specific files when merging</i>"
+msgstr ""
+
+#: commit.py:458 commit.py:459
+msgid "Pending Revisions"
+msgstr ""
+
+#: commit.py:494 commit.py:495
+msgid "Diff for whole tree"
+msgstr ""
+
+#: commit.py:518 commit.py:599 commit.py:519 commit.py:601
+msgid "File commit message"
+msgstr ""
+
+#: commit.py:525 commit.py:526
+msgid "Global Commit Message"
+msgstr ""
+
+#: commit.py:526 commit.py:528
+msgid "<b>Global Commit Message</b>"
+msgstr ""
+
+#: commit.py:552 commit.py:554
+msgid "Diff for "
+msgstr ""
+
+#: commit.py:605 commit.py:607
+msgid "Commit message for "
+msgstr ""
+
+#: commit.py:690 commit.py:692
+msgid "There are no changes in the working tree. Do you want to commit anyway?"
+msgstr ""
+
+#: branchview/treeview.py:400 branchview/treeview.py:402
+msgid "Please wait, loading ancestral graph..."
+msgstr ""
+
+#: olive/__init__.py:71 olive/__init__.py:72
+msgid "Lead Developer:"
+msgstr ""
+
+#: olive/__init__.py:73 olive/__init__.py:74
+msgid "Contributors:"
+msgstr ""
+
+#: olive/__init__.py:578 olive/__init__.py:579
+#, python-format
+msgid "%d local extra revision(s). \n"
+msgstr ""
+
+#: olive/__init__.py:590 olive/__init__.py:591
+#, python-format
+msgid "%d local missing revision(s).\n"
+msgstr ""
+
+#: olive/__init__.py:632 olive/__init__.py:633
+msgid "Update successful but conflicts generated"
+msgstr ""
+
+#: olive/__init__.py:632 olive/__init__.py:633
+#, python-format
+msgid "Number of conflicts generated: %d."
+msgstr ""
+
+#: olive/__init__.py:634 olive/__init__.py:635
+msgid "Update successful"
+msgstr ""
+
+#: olive/__init__.py:634 olive/__init__.py:635
+msgid "No conflicts generated."
+msgstr ""

=== modified file 'push.py'
--- push.py	2007-09-17 10:33:57 +0000
+++ push.py	2008-05-05 18:16:46 +0000
@@ -30,6 +30,7 @@
 from bzrlib.config import LocationConfig
 import bzrlib.errors as errors
 
+from bzrlib.plugins.gtk import _i18n
 from dialog import error_dialog, info_dialog, question_dialog
 
 from history import UrlHistory
@@ -49,9 +50,9 @@
         self.branch = branch
         
         # Create the widgets
-        self._label_location = gtk.Label(_("Location:"))
+        self._label_location = gtk.Label(_i18n("Location:"))
         self._combo = gtk.ComboBoxEntry()
-        self._button_push = gtk.Button(_("_Push"), use_underline=True)
+        self._button_push = gtk.Button(_i18n("_Push"), use_underline=True)
         self._hbox_location = gtk.HBox()
         
         # Set callbacks
@@ -94,22 +95,22 @@
         location = self._combo.get_child().get_text()
         revs = 0
         if self.branch is not None and self.branch.get_push_location() is None:
-            response = question_dialog(_('Set default push location'),
-                                       _('There is no default push location set.\nSet %r as default now?') % location)
+            response = question_dialog(_i18n('Set default push location'),
+                                       _i18n('There is no default push location set.\nSet %r as default now?') % location)
             if response == gtk.RESPONSE_OK:
                 self.branch.set_push_location(location)
 
         try:
             revs = do_push(self.branch, location=location, overwrite=False)
         except errors.DivergedBranches:
-            response = question_dialog(_('Branches have been diverged'),
-                                       _('You cannot push if branches have diverged.\nOverwrite?'))
+            response = question_dialog(_i18n('Branches have been diverged'),
+                                       _i18n('You cannot push if branches have diverged.\nOverwrite?'))
             if response == gtk.RESPONSE_YES:
                 revs = do_push(self.branch, location=location, overwrite=True)
         
         self._history.add_entry(location)
-        info_dialog(_('Push successful'),
-                    _("%d revision(s) pushed.") % revs)
+        info_dialog(_i18n('Push successful'),
+                    _i18n("%d revision(s) pushed.") % revs)
         
         self.response(gtk.RESPONSE_OK)
 
@@ -142,8 +143,8 @@
             relurl = transport.relpath(location_url)
             transport.mkdir(relurl)
         except errors.NoSuchFile:
-            response = question_dialog(_('Non existing parent directory'),
-                         _("The parent directory (%s)\ndoesn't exist. Create?") % location)
+            response = question_dialog(_i18n('Non existing parent directory'),
+                         _i18n("The parent directory (%s)\ndoesn't exist. Create?") % location)
             if response == gtk.RESPONSE_OK:
                 _create_prefix(transport)
             else:

=== modified file 'revbrowser.py'
--- revbrowser.py	2008-04-25 19:41:23 +0000
+++ revbrowser.py	2008-05-05 18:16:46 +0000
@@ -26,6 +26,7 @@
 import gtk
 
 from bzrlib.osutils import format_date
+from bzrlib.plugins.gtk import _i18n
 from bzrlib.plugins.gtk.branchview.treeview import TreeView
 
 
@@ -41,7 +42,7 @@
         self.branch = branch
         
         # Create the widgets
-        self._button_select = gtk.Button(_("_Select"), use_underline=True)
+        self._button_select = gtk.Button(_i18n("_Select"), use_underline=True)
         start_revs = [branch.last_revision(),]
         self.treeview = TreeView(branch, start_revs, None)
         

=== modified file 'status.py'
--- status.py	2008-04-16 00:00:41 +0000
+++ status.py	2008-05-05 18:16:46 +0000
@@ -21,6 +21,8 @@
     pass
 
 import gtk
+from bzrlib.plugins.gtk import _i18n
+
 
 class StatusDialog(gtk.Dialog):
     """ Display Status window and perform the needed actions. """
@@ -79,26 +81,26 @@
         
         if len(delta.added):
             changes = True
-            titer = self.model.append(None, [ _('Added'), None ])
+            titer = self.model.append(None, [ _i18n('Added'), None ])
             for path, id, kind in delta.added:
                 self.model.append(titer, [ path, path ])
 
         if len(delta.removed):
             changes = True
-            titer = self.model.append(None, [ _('Removed'), None ])
+            titer = self.model.append(None, [ _i18n('Removed'), None ])
             for path, id, kind in delta.removed:
                 self.model.append(titer, [ path, path ])
 
         if len(delta.renamed):
             changes = True
-            titer = self.model.append(None, [ _('Renamed'), None ])
+            titer = self.model.append(None, [ _i18n('Renamed'), None ])
             for oldpath, newpath, id, kind, text_modified, meta_modified \
                     in delta.renamed:
                 self.model.append(titer, [ oldpath, newpath ])
 
         if len(delta.modified):
             changes = True
-            titer = self.model.append(None, [ _('Modified'), None ])
+            titer = self.model.append(None, [ _i18n('Modified'), None ])
             for path, id, kind, text_modified, meta_modified in delta.modified:
                 self.model.append(titer, [ path, path ])
         
@@ -106,12 +108,12 @@
         for path in self.wt.unknowns():
             changes = True
             if not done_unknown:
-                titer = self.model.append(None, [ _('Unknown'), None ])
+                titer = self.model.append(None, [ _i18n('Unknown'), None ])
                 done_unknown = True
             self.model.append(titer, [ path, path ])
 
         if not changes:
-            self.model.append(None, [ _('No changes.'), None ])
+            self.model.append(None, [ _i18n('No changes.'), None ])
 
         self.treeview.expand_all()
     

=== modified file 'tags.py'
--- tags.py	2007-11-02 14:49:57 +0000
+++ tags.py	2008-05-23 13:14:58 +0000
@@ -23,6 +23,7 @@
 
 import gtk
 
+from bzrlib.plugins.gtk import _i18n
 from bzrlib.plugins.gtk.revisionview import RevisionView
 from bzrlib.plugins.gtk.window import Window
 
@@ -62,7 +63,7 @@
         self._treeview_tags.connect('cursor-changed', self._on_treeview_changed)
         
         # Set properties
-        self.set_title(_("Tags"))
+        self.set_title(_i18n("Tags"))
         self.set_default_size(600, 400)
         
         self._scrolledwindow_tags.set_policy(gtk.POLICY_AUTOMATIC,
@@ -106,12 +107,12 @@
     
     def _load_tags(self):
         """ Load the tags into the TreeView. """
-        tvcol_name = gtk.TreeViewColumn(_("Tag Name"),
+        tvcol_name = gtk.TreeViewColumn(_i18n("Tag Name"),
                                         gtk.CellRendererText(),
                                         text=0)
         tvcol_name.set_resizable(True)
         
-        tvcol_revid = gtk.TreeViewColumn(_("Revision ID"),
+        tvcol_revid = gtk.TreeViewColumn(_i18n("Revision ID"),
                                          gtk.CellRendererText(),
                                          text=1)
         tvcol_revid.set_resizable(True)
@@ -146,13 +147,13 @@
     
     def _tags_not_supported(self):
         """ Tags are not supported. """
-        self._model.append([_("Tags are not supported by this branch format. Please upgrade."), ""])
+        self._model.append([_i18n("Tags are not supported by this branch format. Please upgrade."), ""])
         self._button_add.set_sensitive(False)
         self._button_remove.set_sensitive(False)
     
     def _no_tags_available(self):
         """ No tags in the branch. """
-        self._model.append([_("No tagged revisions in the branch."), ""])
+        self._model.append([_i18n("No tagged revisions in the branch."), ""])
         self._button_add.set_sensitive(True)
         self._button_remove.set_sensitive(False)
     
@@ -227,7 +228,7 @@
                                                         gtk.ICON_SIZE_DIALOG)
         self._label_title = gtk.Label()
         self._label_question = gtk.Label()
-        self._button_remove = gtk.Button(_("_Remove tag"), use_underline=True)
+        self._button_remove = gtk.Button(_i18n("_Remove tag"), use_underline=True)
         
         # Set callbacks
         self._button_remove.connect('clicked', self._on_remove_clicked)
@@ -237,9 +238,9 @@
         self._hbox.set_spacing(5)
         self._vbox_question.set_spacing(3)
         
-        self._label_title.set_markup(_("<b><big>Remove tag?</big></b>"))
+        self._label_title.set_markup(_i18n("<b><big>Remove tag?</big></b>"))
         self._label_title.set_alignment(0.0, 0.5)
-        self._label_question.set_markup(_("Are you sure you want to remove the tag: <b>%s</b>?") % self.tag)
+        self._label_question.set_markup(_i18n("Are you sure you want to remove the tag: <b>%s</b>?") % self.tag)
         self._label_question.set_alignment(0.0, 0.5)
         
         self._button_remove.set_image(gtk.image_new_from_stock(gtk.STOCK_REMOVE,
@@ -284,10 +285,10 @@
         self._branch = branch
         
         # Create the widgets
-        self._button_add = gtk.Button(_("_Add tag"), use_underline=True)
+        self._button_add = gtk.Button(_i18n("_Add tag"), use_underline=True)
         self._table = gtk.Table(2, 2)
-        self._label_name = gtk.Label(_("Tag Name:"))
-        self._label_revid = gtk.Label(_("Revision ID:"))
+        self._label_name = gtk.Label(_i18n("Tag Name:"))
+        self._label_revid = gtk.Label(_i18n("Revision ID:"))
         self._entry_name = gtk.Entry()
         if self._revid is not None:
             self._hbox_revid = gtk.Label(self._revid)
@@ -318,15 +319,15 @@
     def _on_add_clicked(self, widget):
         """ Add button clicked handler. """
         if len(self._entry_name.get_text()) == 0:
-            error_dialog(_("No tag name specified"),
-                         _("You have to specify the tag's desired name."))
+            error_dialog(_i18n("No tag name specified"),
+                         _i18n("You have to specify the tag's desired name."))
             return
         
         if self._revid is None:
             if self._hbox_revid.get_revision_id() is None:
                 self._revid = self._branch.last_revision()
             else:
-                self._revid = self.hbox_revid.get_revision_id()
+                self._revid = self._hbox_revid.get_revision_id()
             
         self.tagname = self._entry_name.get_text()
         

=== modified file 'tests/test_diff.py'
--- tests/test_diff.py	2008-03-11 13:18:28 +0000
+++ tests/test_diff.py	2008-05-22 19:08:04 +0000
@@ -18,10 +18,33 @@
 from cStringIO import StringIO
 import os
 
-from bzrlib import tests
-
-from bzrlib.plugins.gtk.diff import DiffView, iter_changes_to_status
-
+from bzrlib import errors, tests
+from bzrlib.merge_directive import MergeDirective2
+
+from bzrlib.plugins.gtk.diff import (
+    DiffController,
+    DiffView,
+    iter_changes_to_status,
+    MergeDirectiveController,
+    )
+eg_diff = """\
+=== modified file 'tests/test_diff.py'
+--- tests/test_diff.py	2008-03-11 13:18:28 +0000
++++ tests/test_diff.py	2008-05-08 22:44:02 +0000
+@@ -20,7 +20,11 @@
+ 
+ from bzrlib import tests
+ 
+-from bzrlib.plugins.gtk.diff import DiffView, iter_changes_to_status
++from bzrlib.plugins.gtk.diff import (
++    DiffController,
++    DiffView,
++    iter_changes_to_status,
++    )
+ 
+ 
+ class TestDiffViewSimple(tests.TestCase):
+"""
 
 class TestDiffViewSimple(tests.TestCase):
 
@@ -69,6 +92,122 @@
             )
 
 
+class MockDiffWidget(object):
+
+    def set_diff_text_sections(self, sections):
+        self.sections = list(sections)
+
+
+class MockWindow(object):
+    def __init__(self):
+        self.diff = MockDiffWidget()
+        self.merge_successful = False
+
+    def set_title(self, title):
+        self.title = title
+
+    def _get_save_path(self, basename):
+        return 'save-path'
+
+    def _get_merge_target(self):
+        return 'this'
+
+    def destroy(self):
+        pass
+
+    def _merge_successful(self):
+        self.merge_successful = True
+
+    def _conflicts(self):
+        self.conflicts = True
+
+    def _handle_error(self, e):
+        self.handled_error = e
+
+
+class TestDiffController(tests.TestCaseWithTransport):
+
+    def get_controller(self):
+        window = MockWindow()
+        return DiffController('load-path', eg_diff.splitlines(True), window)
+
+    def test_get_diff_sections(self):
+        controller = self.get_controller()
+        controller = DiffController('.', eg_diff.splitlines(True),
+                                    controller.window)
+        sections = list(controller.get_diff_sections())
+        self.assertEqual('Complete Diff', sections[0][0])
+        self.assertIs(None, sections[0][1])
+        self.assertEqual(eg_diff, sections[0][2])
+
+        self.assertEqual('tests/test_diff.py', sections[1][0])
+        self.assertEqual('tests/test_diff.py', sections[1][1])
+        self.assertEqual(''.join(eg_diff.splitlines(True)[1:]),
+                         sections[1][2])
+
+    def test_initialize_window(self):
+        controller = self.get_controller()
+        controller.initialize_window(controller.window)
+        self.assertEqual(2, len(controller.window.diff.sections))
+        self.assertEqual('load-path - diff', controller.window.title)
+
+    def test_perform_save(self):
+        self.build_tree_contents([('load-path', 'foo')])
+        controller = self.get_controller()
+        controller.perform_save(None)
+        self.assertFileEqual('foo', 'save-path')
+
+
+class TestMergeDirectiveController(tests.TestCaseWithTransport):
+
+    def make_this_other_directive(self):
+        this = self.make_branch_and_tree('this')
+        this.commit('first commit')
+        other = this.bzrdir.sprout('other').open_workingtree()
+        self.build_tree_contents([('other/foo', 'bar')])
+        other.add('foo')
+        other.commit('second commit')
+        other.lock_write()
+        try:
+            directive = MergeDirective2.from_objects(other.branch.repository,
+                                                     other.last_revision(), 0,
+                                                     0, 'this')
+        finally:
+            other.unlock()
+        return this, other, directive
+
+    def make_merged_window(self, directive):
+        window = MockWindow()
+        controller = MergeDirectiveController('directive', directive, window)
+        controller.perform_merge(window)
+        return window
+
+    def test_perform_merge_success(self):
+        this, other, directive = self.make_this_other_directive()
+        window = self.make_merged_window(directive)
+        self.assertTrue(window.merge_successful)
+        self.assertEqual(other.last_revision(), this.get_parent_ids()[1])
+        self.assertFileEqual('bar', 'this/foo')
+
+    def test_perform_merge_conflicts(self):
+        this, other, directive = self.make_this_other_directive()
+        self.build_tree_contents([('this/foo', 'bar')])
+        this.add('foo')
+        this.commit('message')
+        window = self.make_merged_window(directive)
+        self.assertFalse(window.merge_successful)
+        self.assertTrue(window.conflicts)
+        self.assertEqual(other.last_revision(), this.get_parent_ids()[1])
+        self.assertFileEqual('bar', 'this/foo')
+
+    def test_perform_merge_uncommitted_changes(self):
+        this, other, directive = self.make_this_other_directive()
+        self.build_tree_contents([('this/foo', 'bar')])
+        this.add('foo')
+        window = self.make_merged_window(directive)
+        self.assertIsInstance(window.handled_error, errors.UncommittedChanges)
+
+
 class Test_IterChangesToStatus(tests.TestCaseWithTransport):
 
     def assertStatusEqual(self, expected, tree):

=== modified file 'ui.py'
--- ui.py	2008-03-20 16:06:23 +0000
+++ ui.py	2008-05-01 22:24:50 +0000
@@ -86,6 +86,8 @@
 
     def remove(self, pb):
         self.vbox.remove(pb)
+        if len(self.vbox.get_children()) == 0: # If there is nothing to show, don't leave a ghost window here
+             self.destroy()
 
 
 class PasswordDialog(gtk.Dialog):

